/**
 * Hero Section Customizer Preview
 */
( function( $ ) {

    // 最小高さ (vh)
    wp.customize( 'openai_hero_min_height_vh', function( value ) {
        value.bind( function( newval ) {
            $( 'body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"]' ).css( 'min-height', newval + 'vh' );
        } );
    } );

    // 重ね色
    wp.customize( 'openai_hero_overlay_color', function( value ) {
        value.bind( function( newval ) {
            // !importantを維持しつつ色だけ変更 (インラインスタイルを直接操作)
            var targetSelector = 'body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] .wp-block-cover__background, body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] .wp-block-cover__gradient-background';
            var existingStyle = $(targetSelector).attr('style') || '';
            var newStyle = existingStyle.replace(/background-color:[^;]+;?/g, ''); // 既存の背景色を削除
            newStyle += ' background-color: ' + newval + ' !important;'; // 新しい色を追加
            $(targetSelector).attr('style', newStyle);

            // もし既存のインラインスタイルがなければ、直接適用
            if (!existingStyle.includes('background-color')) {
                $(targetSelector).css('background-color', newval + ' !important');
            }
        } );
    } );

    // 重ね色の不透明度
    wp.customize( 'openai_hero_overlay_opacity', function( value ) {
        value.bind( function( newval ) {
             var targetSelector = 'body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] .wp-block-cover__background, body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] .wp-block-cover__gradient-background';
            var existingStyle = $(targetSelector).attr('style') || '';
            var newStyle = existingStyle.replace(/opacity:[^;]+;?/g, ''); // 既存の不透明度を削除
            newStyle += ' opacity: ' + newval + ' !important;'; // 新しい不透明度を追加
            $(targetSelector).attr('style', newStyle);
            
             // もし既存のインラインスタイルがなければ、直接適用
            if (!existingStyle.includes('opacity')) {
                 $(targetSelector).css('opacity', newval + ' !important');
            }
        } );
    } );

    // 角丸 (px)
    wp.customize( 'openai_hero_border_radius', function( value ) {
        value.bind( function( newval ) {
            $( 'body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"]' ).css( 'border-radius', newval + 'px' );
        } );
    } );

    // 内部コンテナのパディング
    var paddingSettings = ['top', 'right', 'bottom', 'left'];
    paddingSettings.forEach(function(pos) {
        wp.customize('openai_hero_inner_padding_' + pos, function(value) {
            value.bind(function(newval) {
                $('body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] .wp-block-cover__inner-container').css('padding-' + pos, newval + 'px');
            });
        });
    });

    // ===== テキスト設定 =====
    
    // 見出しフォントサイズ (PC)
    wp.customize('openai_hero_heading_font_size_pc', function(value) {
        value.bind(function(newval) {
            // メディアクエリは直接変更できないため、スタイルタグを挿入
            var style = '<style id="hero-heading-pc-size">' +
                '@media (min-width: 768px) {' +
                'body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] h1, ' +
                'body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] h2 { ' +
                'font-size: ' + newval + 'px !important;' +
                '}' +
                '}</style>';
            
            $('#hero-heading-pc-size').remove();
            $('head').append(style);
        });
    });
    
    // 見出しフォントサイズ (SP)
    wp.customize('openai_hero_heading_font_size_sp', function(value) {
        value.bind(function(newval) {
            var style = '<style id="hero-heading-sp-size">' +
                '@media (max-width: 767px) {' +
                'body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] h1, ' +
                'body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] h2 { ' +
                'font-size: ' + newval + 'px !important;' +
                '}' +
                '}</style>';
            
            $('#hero-heading-sp-size').remove();
            $('head').append(style);
        });
    });
    
    // 見出しフォントウェイト
    wp.customize('openai_hero_heading_font_weight', function(value) {
        value.bind(function(newval) {
            $('body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] h1, body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] h2').css('font-weight', newval);
        });
    });
    
    // 見出し行の高さ
    wp.customize('openai_hero_heading_line_height', function(value) {
        value.bind(function(newval) {
            $('body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] h1, body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] h2').css('line-height', newval);
        });
    });
    
    // 本文フォントサイズ (PC)
    wp.customize('openai_hero_text_font_size_pc', function(value) {
        value.bind(function(newval) {
            // メディアクエリは直接変更できないため、スタイルタグを挿入
            var style = '<style id="hero-text-pc-size">' +
                '@media (min-width: 768px) {' +
                'body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] p:not(.wp-block-cover-text) { ' +
                'font-size: ' + newval + 'px !important;' +
                '}' +
                '}</style>';
            
            $('#hero-text-pc-size').remove();
            $('head').append(style);
        });
    });
    
    // 本文フォントサイズ (SP)
    wp.customize('openai_hero_text_font_size_sp', function(value) {
        value.bind(function(newval) {
            var style = '<style id="hero-text-sp-size">' +
                '@media (max-width: 767px) {' +
                'body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] p:not(.wp-block-cover-text) { ' +
                'font-size: ' + newval + 'px !important;' +
                '}' +
                '}</style>';
            
            $('#hero-text-sp-size').remove();
            $('head').append(style);
        });
    });
    
    // テキスト配置（横方向）
    wp.customize('openai_hero_text_alignment', function(value) {
        value.bind(function(newval) {
            var $container = $('body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] .wp-block-cover__inner-container');
            $container.css('text-align', newval);
            
            // 水平方向の配置に基づいてalign-itemsを設定
            switch (newval) {
                case 'left':
                    $container.css('align-items', 'flex-start');
                    break;
                case 'center':
                    $container.css('align-items', 'center');
                    break;
                case 'right':
                    $container.css('align-items', 'flex-end');
                    break;
            }
        });
    });
    
    // テキスト配置（垂直方向）
    wp.customize('openai_hero_vertical_alignment', function(value) {
        value.bind(function(newval) {
            var $container = $('body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] .wp-block-cover__inner-container');
            
            // 垂直方向の配置を設定
            switch (newval) {
                case 'top':
                    $container.css('justify-content', 'flex-start');
                    break;
                case 'center':
                    $container.css('justify-content', 'center');
                    break;
                case 'bottom':
                    $container.css('justify-content', 'flex-end');
                    break;
                case 'space-between':
                    $container.css('justify-content', 'space-between');
                    break;
            }
        });
    });
    
    // ===== アニメーション設定 =====
    
    // アニメーション有効化
    wp.customize('openai_hero_enable_animation', function(value) {
        value.bind(function(newval) {
            if (newval) {
                $('.u-fade-in').css({
                    'opacity': '0',
                    'transform': 'translateY(20px)',
                    'transition': 'opacity 0.8s ease-out, transform 0.8s ease-out'
                });
                
                // 既に表示されている要素にis-visibleクラスを追加
                setTimeout(function() {
                    $('.u-fade-in').each(function() {
                        var $this = $(this);
                        var rect = $this[0].getBoundingClientRect();
                        if (rect.top <= window.innerHeight && rect.bottom >= 0) {
                            $this.addClass('is-visible');
                        }
                    });
                }, 100);
            } else {
                $('.u-fade-in').css({
                    'opacity': '1',
                    'transform': 'none',
                    'transition': 'none'
                }).removeClass('is-visible');
            }
        });
    });
    
    // アニメーション種類
    wp.customize('openai_hero_animation_type', function(value) {
        value.bind(function(newval) {
            refreshAnimationSettings();
        });
    });
    
    // アニメーション速度
    wp.customize('openai_hero_animation_speed', function(value) {
        value.bind(function(newval) {
            refreshAnimationSettings();
        });
    });
    
    // アニメーション遅延（基本）
    wp.customize('openai_hero_animation_delay_base', function(value) {
        value.bind(function(newval) {
            refreshAnimationSettings();
        });
    });
    
    // アニメーション遅延（増分）
    wp.customize('openai_hero_animation_delay_increment', function(value) {
        value.bind(function(newval) {
            refreshAnimationSettings();
        });
    });
    
    // アニメーション設定をリフレッシュする関数
    function refreshAnimationSettings() {
        var enable = wp.customize('openai_hero_enable_animation').get();
        if (!enable) return;
        
        var type = wp.customize('openai_hero_animation_type').get();
        var speed = wp.customize('openai_hero_animation_speed').get();
        var delay_base = wp.customize('openai_hero_animation_delay_base').get();
        var delay_increment = wp.customize('openai_hero_animation_delay_increment').get();
        
        // 要素リセット
        $('.u-fade-in').css({
            'opacity': '0',
            'transform': '',
            'transition': '',
            'animation': ''
        });
        
        // アニメーション種類に応じたスタイル適用
        switch (type) {
            case 'fade-in':
                $('.u-fade-in').css({
                    'opacity': '0',
                    'transform': 'translateY(20px)',
                    'transition': 'opacity ' + speed + 's ease-out, transform ' + speed + 's ease-out'
                });
                break;
            case 'slide-up':
                $('.u-fade-in').css({
                    'opacity': '0',
                    'transform': 'translateY(50px)',
                    'transition': 'opacity ' + speed + 's ease-out, transform ' + speed + 's ease-out'
                });
                break;
            case 'slide-left':
                $('.u-fade-in').css({
                    'opacity': '0',
                    'transform': 'translateX(50px)',
                    'transition': 'opacity ' + speed + 's ease-out, transform ' + speed + 's ease-out'
                });
                break;
            case 'slide-right':
                $('.u-fade-in').css({
                    'opacity': '0',
                    'transform': 'translateX(-50px)',
                    'transition': 'opacity ' + speed + 's ease-out, transform ' + speed + 's ease-out'
                });
                break;
            case 'zoom-in':
                $('.u-fade-in').css({
                    'opacity': '0',
                    'transform': 'scale(0.8)',
                    'transition': 'opacity ' + speed + 's ease-out, transform ' + speed + 's ease-out'
                });
                break;
            case 'bounce':
                $('.u-fade-in').css({
                    'opacity': '0',
                    'transition': 'opacity ' + speed + 's ease-out'
                });
                break;
        }
        
        // 遅延スタイル
        $('.u-fade-in-delay-1').css('transition-delay', delay_base + 's');
        $('.u-fade-in-delay-2').css('transition-delay', (parseFloat(delay_base) + parseFloat(delay_increment)) + 's');
        $('.u-fade-in-delay-3').css('transition-delay', (parseFloat(delay_base) + (parseFloat(delay_increment) * 2)) + 's');
        
        // プレビュー用に要素を表示
        setTimeout(function() {
            $('.u-fade-in').addClass('is-visible');
            
            if (type === 'bounce') {
                $('.u-fade-in.is-visible').css({
                    'animation': 'heroSectionBounce ' + speed + 's'
                });
            }
        }, 300);
    }
    
    // ===== ボタン設定 =====
    
    // ボタン背景色
    wp.customize('openai_hero_button_bg_color', function(value) {
        value.bind(function(newval) {
            $('body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] .wp-block-button__link').css('background-color', newval + ' !important');
        });
    });
    
    // ボタンテキスト色
    wp.customize('openai_hero_button_text_color', function(value) {
        value.bind(function(newval) {
            $('body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] .wp-block-button__link').css('color', newval + ' !important');
        });
    });
    
    // ボタン角丸
    wp.customize('openai_hero_button_border_radius', function(value) {
        value.bind(function(newval) {
            $('body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] .wp-block-button__link').css('border-radius', newval + 'px !important');
        });
    });
    
    // ボタンホバーエフェクト
    wp.customize('openai_hero_button_hover_effect', function(value) {
        value.bind(function(newval) {
            var style = '<style id="hero-button-hover">';
            
            switch (newval) {
                case 'lift':
                    style += '.u-lift { transition: transform 0.3s ease, box-shadow 0.3s ease; }' +
                            '.u-lift:hover { transform: translateY(-5px); box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05); }';
                    break;
                case 'scale':
                    style += '.u-lift { transition: transform 0.3s ease; }' +
                            '.u-lift:hover { transform: scale(1.05); }';
                    break;
                case 'shadow':
                    style += '.u-lift { transition: box-shadow 0.3s ease; }' +
                            '.u-lift:hover { box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.2), 0 4px 6px -2px rgba(0, 0, 0, 0.1); }';
                    break;
                case 'color-shift':
                    var bgColor = wp.customize('openai_hero_button_bg_color').get();
                    // 背景色を明るくする（簡易的な実装）
                    style += '.u-lift { transition: background-color 0.3s ease; }' +
                            '.u-lift:hover { background-color: #f8f8f8 !important; }';
                    break;
                case 'none':
                    style += '.u-lift { transition: none; }' +
                            '.u-lift:hover { transform: none; box-shadow: none; }';
                    break;
            }
            
            style += '</style>';
            $('#hero-button-hover').remove();
            $('head').append(style);
        });
    });
    
    // メディアクエリが変更された時の処理（レスポンシブプレビュー用）
    $(window).resize(function() {
        // PCとSPで異なる設定がある場合は、ここで切り替え
        var width = $(window).width();
        if (width >= 768) {
            // PCサイズ
            var headingFontSizePC = wp.customize('openai_hero_heading_font_size_pc').get();
            var textFontSizePC = wp.customize('openai_hero_text_font_size_pc').get();
            
            $('body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] h1, body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] h2').css('font-size', headingFontSizePC + 'px');
            $('body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] p:not(.wp-block-cover-text)').css('font-size', textFontSizePC + 'px');
        } else {
            // SPサイズ
            var headingFontSizeSP = wp.customize('openai_hero_heading_font_size_sp').get();
            var textFontSizeSP = wp.customize('openai_hero_text_font_size_sp').get();
            
            $('body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] h1, body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] h2').css('font-size', headingFontSizeSP + 'px');
            $('body.home .wp-block-cover.alignfull[class*="is-style-openai-hero-"] p:not(.wp-block-cover-text)').css('font-size', textFontSizeSP + 'px');
        }
    });

} )( jQuery ); 