/**
 * OpenAI Style Button Block
 */
(function(blocks, element, blockEditor) {
    var el = element.createElement;
    var useBlockProps = blockEditor.useBlockProps;
    var TextControl = wp.components.TextControl;
    var SelectControl = wp.components.SelectControl;
    var InspectorControls = blockEditor.InspectorControls;
    var PanelBody = wp.components.PanelBody;
    var ToggleControl = wp.components.ToggleControl;
    var ColorPalette = wp.components.ColorPalette;
    var RangeControl = wp.components.RangeControl;
    var colors = wp.data.select('core/editor').getEditorSettings().colors || [];

    blocks.registerBlockType('my-openai-theme/button', {
        title: 'OpenAI Button',
        icon: 'button',
        category: 'design',
        attributes: {
            buttonText: {
                type: 'string',
                default: 'ボタンテキスト'
            },
            buttonUrl: {
                type: 'string',
                default: '' // デフォルトのURLを空に変更
            },
            buttonStyle: {
                type: 'string',
                default: 'standard' // standard, pill, ghost
            },
            buttonSize: {
                type: 'string',
                default: 'medium' // small, medium, large
            },
            backgroundColor: {
                type: 'string',
                default: '' // デフォルトの背景色（空の場合はCSSのデフォルト値が使用される）
            },
            hoverColor: {
                type: 'string',
                default: '' // ホバー時の背景色
            },
            borderRadius: {
                type: 'number',
                default: 8 // デフォルトの角丸サイズ
            },
            buttonWidth: {
                type: 'string',
                default: '' // ボタンの幅（空の場合は自動）
            },
            buttonPadding: {
                type: 'number',
                default: 0 // パディングの追加量
            },
            openInNewTab: {
                type: 'boolean',
                default: false
            },
            align: {
                type: 'string',
                default: 'center' // left, center, right
            }
        },

        edit: function(props) {
            var blockProps = useBlockProps({
                className: 'openai-button-block-editor'
            });
            
            var attributes = props.attributes;
            
            function onChangeButtonText(newText) {
                props.setAttributes({buttonText: newText});
            }
            
            function onChangeButtonUrl(newUrl) {
                props.setAttributes({buttonUrl: newUrl});
            }
            
            function onChangeButtonStyle(newStyle) {
                props.setAttributes({buttonStyle: newStyle});
            }
            
            function onChangeButtonSize(newSize) {
                props.setAttributes({buttonSize: newSize});
            }
            
            function onChangeOpenInNewTab(newValue) {
                props.setAttributes({openInNewTab: newValue});
            }
            
            function onChangeAlign(newAlign) {
                props.setAttributes({align: newAlign});
            }

            function onChangeBackgroundColor(newColor) {
                props.setAttributes({backgroundColor: newColor});
            }

            function onChangeHoverColor(newColor) {
                props.setAttributes({hoverColor: newColor});
            }

            function onChangeBorderRadius(newRadius) {
                props.setAttributes({borderRadius: newRadius});
            }

            function onChangeButtonWidth(newWidth) {
                props.setAttributes({buttonWidth: newWidth});
            }

            function onChangeButtonPadding(newPadding) {
                props.setAttributes({buttonPadding: newPadding});
            }
            
            var inspectorControls = el(
                InspectorControls,
                {},
                el(
                    PanelBody,
                    { title: '基本設定', initialOpen: true },
                    el(
                        TextControl,
                        {
                            label: 'ボタンテキスト',
                            value: attributes.buttonText,
                            onChange: onChangeButtonText
                        }
                    ),
                    el(
                        TextControl,
                        {
                            label: 'URL',
                            value: attributes.buttonUrl,
                            onChange: onChangeButtonUrl,
                            placeholder: 'URLを入力してください'
                        }
                    ),
                    el(
                        SelectControl,
                        {
                            label: 'スタイル',
                            value: attributes.buttonStyle,
                            options: [
                                { label: '標準', value: 'standard' },
                                { label: '丸型', value: 'pill' },
                                { label: 'ゴースト (枠線のみ)', value: 'ghost' }
                            ],
                            onChange: onChangeButtonStyle
                        }
                    ),
                    el(
                        SelectControl,
                        {
                            label: 'サイズ',
                            value: attributes.buttonSize,
                            options: [
                                { label: '小', value: 'small' },
                                { label: '中', value: 'medium' },
                                { label: '大', value: 'large' }
                            ],
                            onChange: onChangeButtonSize
                        }
                    ),
                    el(
                        SelectControl,
                        {
                            label: '配置',
                            value: attributes.align,
                            options: [
                                { label: '左', value: 'left' },
                                { label: '中央', value: 'center' },
                                { label: '右', value: 'right' }
                            ],
                            onChange: onChangeAlign
                        }
                    ),
                    el(
                        ToggleControl,
                        {
                            label: '新しいタブで開く',
                            checked: attributes.openInNewTab,
                            onChange: onChangeOpenInNewTab
                        }
                    )
                ),
                el(
                    PanelBody,
                    { title: 'スタイル設定', initialOpen: false },
                    el(
                        'div',
                        { className: 'components-base-control' },
                        el(
                            'label',
                            { className: 'components-base-control__label' },
                            '背景色'
                        ),
                        el(
                            ColorPalette,
                            {
                                colors: colors,
                                value: attributes.backgroundColor,
                                onChange: onChangeBackgroundColor,
                                disableCustomColors: false,
                                clearable: true
                            }
                        )
                    ),
                    el(
                        'div',
                        { className: 'components-base-control' },
                        el(
                            'label',
                            { className: 'components-base-control__label' },
                            'ホバー時の色'
                        ),
                        el(
                            ColorPalette,
                            {
                                colors: colors,
                                value: attributes.hoverColor,
                                onChange: onChangeHoverColor,
                                disableCustomColors: false,
                                clearable: true
                            }
                        )
                    ),
                    el(
                        RangeControl,
                        {
                            label: '角丸の大きさ',
                            value: attributes.borderRadius,
                            onChange: onChangeBorderRadius,
                            min: 0,
                            max: 50,
                            initialPosition: 8
                        }
                    ),
                    el(
                        SelectControl,
                        {
                            label: 'ボタンの幅',
                            value: attributes.buttonWidth,
                            options: [
                                { label: '自動 (テキストに合わせる)', value: '' },
                                { label: '25%', value: '25%' },
                                { label: '50%', value: '50%' },
                                { label: '75%', value: '75%' },
                                { label: '100% (全幅)', value: '100%' }
                            ],
                            onChange: onChangeButtonWidth
                        }
                    ),
                    el(
                        RangeControl,
                        {
                            label: 'パディング調整',
                            value: attributes.buttonPadding,
                            onChange: onChangeButtonPadding,
                            min: -10,
                            max: 30,
                            initialPosition: 0
                        }
                    )
                )
            );
            
            // スタイルに応じたクラス名を生成
            var buttonClass = 'openai-button';
            if (attributes.buttonStyle === 'pill') {
                buttonClass += ' openai-button-pill';
            } else if (attributes.buttonStyle === 'ghost') {
                buttonClass += ' openai-button-ghost';
            }
            
            // サイズに応じたクラス名を追加
            buttonClass += ' openai-button-' + attributes.buttonSize;
            
            // 配置に応じたスタイルを設定
            var containerStyle = { textAlign: attributes.align };
            if (attributes.buttonWidth) {
                containerStyle.width = '100%';
            }
            
            // ボタンのスタイル（背景色など）
            var buttonStyle = {};
            
            // 背景色
            if (attributes.backgroundColor && attributes.buttonStyle !== 'ghost') {
                buttonStyle.backgroundColor = attributes.backgroundColor;
                // 背景色が明るい場合はテキスト色を暗くする
                if (isLightColor(attributes.backgroundColor)) {
                    buttonStyle.color = '#202123';
                }
            } else if (attributes.backgroundColor && attributes.buttonStyle === 'ghost') {
                buttonStyle.borderColor = attributes.backgroundColor;
                buttonStyle.color = attributes.backgroundColor;
            }
            
            // カスタム角丸
            if (attributes.borderRadius !== undefined) {
                if (attributes.buttonStyle === 'pill') {
                    // 丸型の場合は大きめの値に
                    buttonStyle.borderRadius = Math.max(20, attributes.borderRadius) + 'px';
                } else {
                    buttonStyle.borderRadius = attributes.borderRadius + 'px';
                }
            }
            
            // カスタム幅
            if (attributes.buttonWidth) {
                buttonStyle.width = attributes.buttonWidth;
                buttonStyle.display = 'inline-block';
            }
            
            // パディング調整
            if (attributes.buttonPadding !== 0) {
                var basePadding;
                if (attributes.buttonSize === 'small') {
                    basePadding = [8, 16];
                } else if (attributes.buttonSize === 'medium') {
                    basePadding = [10, 24];
                } else {
                    basePadding = [12, 32];
                }
                
                buttonStyle.padding = (basePadding[0] + attributes.buttonPadding) + 'px ' + 
                                     (basePadding[1] + attributes.buttonPadding) + 'px';
            }
            
            // プレビュー表示の改善
            var preview = el(
                'div',
                { style: containerStyle, className: 'openai-button-container' },
                el(
                    'a',
                    {
                        href: 'javascript:void(0)', // エディタでのプレビューリンク
                        className: buttonClass,
                        style: buttonStyle,
                        onClick: function(e) { e.preventDefault(); }, // クリックを無効化
                        'data-hover-color': attributes.hoverColor || undefined // ホバー色を data 属性に保存
                    },
                    attributes.buttonText
                )
            );
            
            return el(
                'div',
                blockProps,
                inspectorControls,
                preview
            );
        },

        save: function(props) {
            var attributes = props.attributes;
            
            // スタイルに応じたクラス名を生成
            var buttonClass = 'openai-button';
            if (attributes.buttonStyle === 'pill') {
                buttonClass += ' openai-button-pill';
            } else if (attributes.buttonStyle === 'ghost') {
                buttonClass += ' openai-button-ghost';
            }
            
            // サイズに応じたクラス名を追加
            buttonClass += ' openai-button-' + attributes.buttonSize;
            
            // 配置に応じたスタイルを設定
            var containerStyle = { textAlign: attributes.align };
            if (attributes.buttonWidth) {
                containerStyle.width = '100%';
            }
            
            // ボタンのスタイル（背景色など）
            var buttonStyle = {};
            
            // 背景色
            if (attributes.backgroundColor && attributes.buttonStyle !== 'ghost') {
                buttonStyle.backgroundColor = attributes.backgroundColor;
                // 背景色が明るい場合はテキスト色を暗くする
                if (isLightColor(attributes.backgroundColor)) {
                    buttonStyle.color = '#202123';
                }
            } else if (attributes.backgroundColor && attributes.buttonStyle === 'ghost') {
                buttonStyle.borderColor = attributes.backgroundColor;
                buttonStyle.color = attributes.backgroundColor;
            }
            
            // カスタム角丸
            if (attributes.borderRadius !== undefined) {
                if (attributes.buttonStyle === 'pill') {
                    // 丸型の場合は大きめの値に
                    buttonStyle.borderRadius = Math.max(20, attributes.borderRadius) + 'px';
                } else {
                    buttonStyle.borderRadius = attributes.borderRadius + 'px';
                }
            }
            
            // カスタム幅
            if (attributes.buttonWidth) {
                buttonStyle.width = attributes.buttonWidth;
                buttonStyle.display = 'inline-block';
            }
            
            // パディング調整
            if (attributes.buttonPadding !== 0) {
                var basePadding;
                if (attributes.buttonSize === 'small') {
                    basePadding = [8, 16];
                } else if (attributes.buttonSize === 'medium') {
                    basePadding = [10, 24];
                } else {
                    basePadding = [12, 32];
                }
                
                buttonStyle.padding = (basePadding[0] + attributes.buttonPadding) + 'px ' + 
                                     (basePadding[1] + attributes.buttonPadding) + 'px';
            }
            
            // URLが空の場合の処理
            var href = attributes.buttonUrl || 'javascript:void(0)';
            var onClick = !attributes.buttonUrl ? 'event.preventDefault()' : '';
            
            return el(
                'div',
                { style: containerStyle, className: 'openai-button-container' },
                el(
                    'a',
                    {
                        href: href,
                        className: buttonClass,
                        style: buttonStyle,
                        target: attributes.openInNewTab ? '_blank' : '',
                        rel: attributes.openInNewTab ? 'noopener noreferrer' : '',
                        onClick: onClick,
                        'data-hover-color': attributes.hoverColor || undefined // ホバー色を data 属性に保存
                    },
                    attributes.buttonText
                )
            );
        }
    });

    // 明るい色かどうかを判定する関数
    function isLightColor(hexColor) {
        if (!hexColor) return false;
        
        // 16進数の色コードをRGBに変換
        var r, g, b;
        if (hexColor.length === 4) {
            r = parseInt(hexColor[1] + hexColor[1], 16);
            g = parseInt(hexColor[2] + hexColor[2], 16);
            b = parseInt(hexColor[3] + hexColor[3], 16);
        } else {
            r = parseInt(hexColor.substring(1, 3), 16);
            g = parseInt(hexColor.substring(3, 5), 16);
            b = parseInt(hexColor.substring(5, 7), 16);
        }
        
        // 明るさの計算（YIQ式）
        var yiq = ((r * 299) + (g * 587) + (b * 114)) / 1000;
        return yiq >= 128; // 128以上なら明るい色
    }

    // ページ読み込み時にボタン要素をチェックして初期化
    document.addEventListener('DOMContentLoaded', function() {
        initOpenAIButtons();
    });

    // ボタンの初期化処理
    function initOpenAIButtons() {
        var buttons = document.querySelectorAll('.openai-button');
        buttons.forEach(function(button) {
            // リンクなしのボタンの処理
            if (button.getAttribute('href') === 'javascript:void(0)') {
                button.addEventListener('click', function(e) {
                    e.preventDefault();
                });
            }
            
            // ホバー色の処理
            var hoverColor = button.getAttribute('data-hover-color');
            if (hoverColor) {
                button.addEventListener('mouseenter', function() {
                    var originalBgColor = this.style.backgroundColor;
                    var originalColor = this.style.color;
                    var isGhost = this.classList.contains('openai-button-ghost');
                    
                    // 元の色を記憶
                    if (!this.hasAttribute('data-original-bg')) {
                        this.setAttribute('data-original-bg', originalBgColor || '');
                    }
                    if (!this.hasAttribute('data-original-color')) {
                        this.setAttribute('data-original-color', originalColor || '');
                    }
                    
                    // ホバー色を適用
                    if (isGhost) {
                        this.style.borderColor = hoverColor;
                        this.style.color = hoverColor;
                    } else {
                        this.style.backgroundColor = hoverColor;
                        // 明るい色の場合は文字色を調整
                        if (isLightColor(hoverColor)) {
                            this.style.color = '#202123';
                        } else {
                            this.style.color = '#ffffff';
                        }
                    }
                });
                
                button.addEventListener('mouseleave', function() {
                    var originalBgColor = this.getAttribute('data-original-bg');
                    var originalColor = this.getAttribute('data-original-color');
                    var isGhost = this.classList.contains('openai-button-ghost');
                    
                    // 元の色に戻す
                    if (isGhost) {
                        this.style.borderColor = originalBgColor || '';
                        this.style.color = originalColor || '';
                    } else {
                        this.style.backgroundColor = originalBgColor || '';
                        this.style.color = originalColor || '';
                    }
                });
            }
        });
    }
}(
    window.wp.blocks,
    window.wp.element,
    window.wp.blockEditor
)); 