/**
 * OpenAI Button Custom Effects
 * フロントエンド側でのカスタムボタン効果を実装するスクリプト
 */
(function() {
    'use strict';

    // ドキュメント読み込み完了時に実行
    document.addEventListener('DOMContentLoaded', function() {
        initOpenAIButtonEffects();
    });

    /**
     * OpenAIボタンの効果を初期化する
     */
    function initOpenAIButtonEffects() {
        var buttons = document.querySelectorAll('.openai-button');
        
        buttons.forEach(function(button) {
            // リンクなしのボタンの処理
            if (button.getAttribute('href') === 'javascript:void(0)') {
                button.addEventListener('click', function(e) {
                    e.preventDefault();
                });
            }
            
            // ホバー色の処理
            var hoverColor = button.getAttribute('data-hover-color');
            if (hoverColor) {
                button.addEventListener('mouseenter', function() {
                    var originalBgColor = this.style.backgroundColor;
                    var originalColor = this.style.color;
                    var originalBorderColor = this.style.borderColor;
                    var isGhost = this.classList.contains('openai-button-ghost');
                    
                    // 元の色を記憶
                    if (!this.hasAttribute('data-original-bg')) {
                        this.setAttribute('data-original-bg', originalBgColor || '');
                    }
                    if (!this.hasAttribute('data-original-color')) {
                        this.setAttribute('data-original-color', originalColor || '');
                    }
                    if (!this.hasAttribute('data-original-border')) {
                        this.setAttribute('data-original-border', originalBorderColor || '');
                    }
                    
                    // ホバー色を適用
                    if (isGhost) {
                        this.style.borderColor = hoverColor;
                        this.style.color = hoverColor;
                    } else {
                        this.style.backgroundColor = hoverColor;
                        // 明るい色の場合は文字色を調整
                        if (isLightColor(hoverColor)) {
                            this.style.color = '#202123';
                        } else {
                            this.style.color = '#ffffff';
                        }
                    }
                });
                
                button.addEventListener('mouseleave', function() {
                    var originalBgColor = this.getAttribute('data-original-bg');
                    var originalColor = this.getAttribute('data-original-color');
                    var originalBorderColor = this.getAttribute('data-original-border');
                    var isGhost = this.classList.contains('openai-button-ghost');
                    
                    // 元の色に戻す
                    if (isGhost) {
                        this.style.borderColor = originalBorderColor || '';
                        this.style.color = originalColor || '';
                    } else {
                        this.style.backgroundColor = originalBgColor || '';
                        this.style.color = originalColor || '';
                    }
                });
            }
        });
    }
    
    /**
     * 明るい色かどうかを判定する関数
     * @param {string} hexColor - 16進数の色コード
     * @return {boolean} - 明るい色の場合はtrue
     */
    function isLightColor(hexColor) {
        if (!hexColor) return false;
        
        // #を削除
        hexColor = hexColor.replace(/^#/, '');
        
        // 16進数の色コードをRGBに変換
        var r, g, b;
        if (hexColor.length === 3) {
            r = parseInt(hexColor[0] + hexColor[0], 16);
            g = parseInt(hexColor[1] + hexColor[1], 16);
            b = parseInt(hexColor[2] + hexColor[2], 16);
        } else {
            r = parseInt(hexColor.substring(0, 2), 16);
            g = parseInt(hexColor.substring(2, 4), 16);
            b = parseInt(hexColor.substring(4, 6), 16);
        }
        
        // 明るさの計算（YIQ式）
        var yiq = ((r * 299) + (g * 587) + (b * 114)) / 1000;
        return yiq >= 128; // 128以上なら明るい色
    }
})(); 