<?php
/**
 * @package Arkhe
 * @author LOOS,Inc.
 * @link https://arkhe-theme.com/
 */

/**
 * パス・URIの定数化
 */
define( 'ARKHE_THEME_PATH', get_template_directory() );
define( 'ARKHE_THEME_URI', get_template_directory_uri() );

// 子テーマ用のパス, URI
if ( ! defined( 'ARKHE_CHILD_PATH' ) ) {
	define( 'ARKHE_CHILD_PATH', get_stylesheet_directory() );
}
if ( ! defined( 'ARKHE_CHILD_URI' ) ) {
	define( 'ARKHE_CHILD_URI', get_stylesheet_directory_uri() );
}


/**
 * 翻訳の読み込み
 */
load_theme_textdomain( 'arkhe', ARKHE_THEME_PATH . '/languages' );


/**
 * CLASSのオートロード
 */
spl_autoload_register(
	function( $classname ) {

		// 名前に Arkhe_Theme がなければオートロードしない。
		if ( strpos( $classname, 'Arkhe_Theme' ) === false ) return;

		$classname = str_replace( '\\', '/', $classname );
		$classname = str_replace( 'Arkhe_Theme/', '', $classname );
		$file      = ARKHE_THEME_PATH . '/classes/' . $classname . '.php';

		if ( file_exists( $file ) ) require $file;
	}
);


/**
 * Arkhe_Theme
 */
class Arkhe extends \Arkhe_Theme\Data {

	use \Arkhe_Theme\Utility\Attrs,
		\Arkhe_Theme\Utility\Get,
		\Arkhe_Theme\Utility\SVG,
		\Arkhe_Theme\Utility\Image,
		\Arkhe_Theme\Utility\Parts,
		\Arkhe_Theme\Utility\Output,
		\Arkhe_Theme\Utility\Licence,
		\Arkhe_Theme\Utility\Condition;

	public function __construct() {

		// データをセット
		self::init();

		// 定数定義
		require_once ARKHE_THEME_PATH . '/inc/consts.php';

		// テーマサポート機能
		require_once ARKHE_THEME_PATH . '/inc/theme_support.php';

		// ファイル読み込み
		require_once ARKHE_THEME_PATH . '/inc/enqueue_scripts.php';

		// カスタマイザー
		require_once ARKHE_THEME_PATH . '/inc/customizer.php';

		// カスタムメニュー
		require_once ARKHE_THEME_PATH . '/inc/custom_menu.php';

		// ウィジェット
		require_once ARKHE_THEME_PATH . '/inc/widget.php';

		// Gutenberg
		require_once ARKHE_THEME_PATH . '/inc/gutenberg.php';

		// クラシックエディター
		require_once ARKHE_THEME_PATH . '/inc/tinymce.php';

		// プラガブル関数
		require_once ARKHE_THEME_PATH . '/inc/pluggable.php';

		// 出力処理
		require_once ARKHE_THEME_PATH . '/inc/output.php';

		// その他、フック処理
		require_once ARKHE_THEME_PATH . '/inc/hooks.php';

		// 後方互換用関数
		require_once ARKHE_THEME_PATH . '/inc/backward.php';

		if ( is_admin() ) {
			// Notice
			require_once ARKHE_THEME_PATH . '/inc/notice.php';

			// テーマページ
			require_once ARKHE_THEME_PATH . '/inc/theme_menu.php';
		}

		// アップデート時の処理
		if ( is_admin() || is_user_logged_in() ) {
			require_once ARKHE_THEME_PATH . '/inc/update.php';
		}
	}
}


/**
 * Start!
 */
new \Arkhe();


/**
 * Register custom block patterns based on OpenAI design.
 */
function my_openai_theme_register_block_patterns() {
	// Register Heading (H2) Pattern
	register_block_pattern(
		'my-openai-theme/heading-h2',
		array(
			'title'       => __( 'OpenAI 見出し (H2)', 'my-openai-theme' ),
			'description' => __( 'OpenAIサイト風のH2見出しブロック', 'my-openai-theme' ),
			'categories'  => array( 'text' ),
			'keywords'    => array( 'heading', 'title', 'openai' ),
			'content'     => '<!-- wp:heading {"level":2,"className":"is-style-openai-heading-h2"} -->
<h2 class="wp-block-heading is-style-openai-heading-h2">見出しを入力...</h2>
<!-- /wp:heading -->',
		)
	);

	// Register Paragraph Pattern
	register_block_pattern(
		'my-openai-theme/paragraph',
		array(
			'title'       => __( 'OpenAI 段落', 'my-openai-theme' ),
			'description' => __( 'OpenAIサイト風の標準段落ブロック', 'my-openai-theme' ),
			'categories'  => array( 'text' ),
			'keywords'    => array( 'paragraph', 'text', 'openai' ),
			'content'     => '<!-- wp:paragraph {"className":"is-style-openai-paragraph"} -->
<p class="is-style-openai-paragraph">段落テキストを入力...</p>
<!-- /wp:paragraph -->',
		)
	);

	// Register Button Patterns
	register_block_pattern(
		'my-openai-theme/button-standard',
		array(
			'title'       => __( 'OpenAI 標準ボタン', 'my-openai-theme' ),
			'description' => __( 'OpenAIサイト風の標準ボタン', 'my-openai-theme' ),
			'categories'  => array( 'buttons', 'openai-patterns' ),
			'keywords'    => array( 'button', 'openai' ),
			'content'     => '<!-- wp:buttons {"align":"center"} -->
<div class="wp-block-buttons aligncenter"><!-- wp:button {"className":"is-style-openai-button"} -->
<div class="wp-block-button is-style-openai-button"><a class="wp-block-button__link">ボタンテキスト</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons -->',
		)
	);

	register_block_pattern(
		'my-openai-theme/button-pill',
		array(
			'title'       => __( 'OpenAI 丸型ボタン', 'my-openai-theme' ),
			'description' => __( 'OpenAIサイト風の丸型ボタン', 'my-openai-theme' ),
			'categories'  => array( 'buttons', 'openai-patterns' ),
			'keywords'    => array( 'button', 'rounded', 'openai' ),
			'content'     => '<!-- wp:buttons {"align":"center"} -->
<div class="wp-block-buttons aligncenter"><!-- wp:button {"className":"is-style-openai-button-pill"} -->
<div class="wp-block-button is-style-openai-button-pill"><a class="wp-block-button__link">ボタンテキスト</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons -->',
		)
	);

	register_block_pattern(
		'my-openai-theme/button-ghost',
		array(
			'title'       => __( 'OpenAI ゴーストボタン', 'my-openai-theme' ),
			'description' => __( 'OpenAIサイト風の枠線のみのボタン', 'my-openai-theme' ),
			'categories'  => array( 'buttons', 'openai-patterns' ),
			'keywords'    => array( 'button', 'ghost', 'outline', 'openai' ),
			'content'     => '<!-- wp:buttons {"align":"center"} -->
<div class="wp-block-buttons aligncenter"><!-- wp:button {"className":"is-style-openai-button-ghost"} -->
<div class="wp-block-button is-style-openai-button-ghost"><a class="wp-block-button__link">ボタンテキスト</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons -->',
		)
	);

	// Register YouTube Embed Pattern
	register_block_pattern(
		'my-openai-theme/youtube-embed',
		array(
			'title'       => __( 'OpenAI YouTube動画', 'my-openai-theme' ),
			'description' => __( 'OpenAIスタイルのYouTube動画埋め込みブロック', 'my-openai-theme' ),
			'categories'  => array( 'media', 'embed', 'openai-patterns' ),
			'keywords'    => array( 'video', 'youtube', 'embed', 'openai' ),
			'content'     => '<!-- wp:html -->
<div class="openai-youtube-container">
    <div class="openai-youtube-wrapper">
        <iframe width="560" height="315" src="https://www.youtube.com/embed/VIDEO_ID_HERE" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
    </div>
    <div class="openai-youtube-title">動画タイトルをここに入力</div>
</div>
<!-- /wp:html -->',
		)
	);

	// --- 他のパターンもここに追加 --- 
}
add_action( 'init', 'my_openai_theme_register_block_patterns' );

/**
 * Register block pattern categories.
 */
function my_openai_theme_register_block_pattern_categories() {
	register_block_pattern_category(
		'openai-patterns',
		array( 'label' => __( 'OpenAI Patterns', 'my-openai-theme' ) )
	);
}
add_action( 'init', 'my_openai_theme_register_block_pattern_categories' );

add_action( 'wp_enqueue_scripts', 'my_openai_theme_enqueue_scripts' );

/**
 * Register custom block styles for OpenAI theme
 */
function my_openai_theme_register_block_styles() {
	// ボタン用のOpenAIスタイルを登録
	register_block_style(
		'core/button',
		array(
			'name'         => 'openai-button',
			'label'        => __( 'OpenAI ボタン', 'my-openai-theme' ),
			'style_handle' => 'my-openai-theme',
		)
	);

	// より丸いボタンスタイル
	register_block_style(
		'core/button',
		array(
			'name'         => 'openai-button-pill',
			'label'        => __( 'OpenAI 丸型ボタン', 'my-openai-theme' ),
			'style_handle' => 'my-openai-theme',
		)
	);
	
	// ゴーストボタン（枠線のみ）スタイル
	register_block_style(
		'core/button',
		array(
			'name'         => 'openai-button-ghost',
			'label'        => __( 'OpenAI ゴーストボタン', 'my-openai-theme' ),
			'style_handle' => 'my-openai-theme',
		)
	);
}
add_action( 'init', 'my_openai_theme_register_block_styles' );

function my_openai_theme_enqueue_scripts() {
	// ヘッダー機能用のJavaScript
	wp_enqueue_script(
		'my-openai-header',
		get_stylesheet_directory_uri() . '/assets/js/header.js',
		array(),
		'1.0.0',
		true
	);
	
	// YouTube埋め込み機能用のJavaScript
	wp_enqueue_script(
		'my-openai-youtube',
		get_stylesheet_directory_uri() . '/assets/js/youtube-embed.js',
		array(),
		'1.0.0',
		true
	);
    
    // OpenAIボタンスタイルを読み込み
    wp_enqueue_style(
        'my-openai-button',
        get_stylesheet_directory_uri() . '/assets/css/openai-button.css',
        array(),
        '1.0.0'
    );
    
    // OpenAIフッタースタイルを読み込み
    wp_enqueue_style(
        'my-openai-footer',
        get_stylesheet_directory_uri() . '/assets/css/openai-footer.css',
        array(),
        '1.0.0'
    );
    
    // OpenAIボタンカスタム効果用のJavaScript
    wp_enqueue_script(
        'my-openai-button-custom',
        get_stylesheet_directory_uri() . '/assets/js/openai-button-custom.js',
        array(),
        '1.0.0',
        true
    );
}

/**
 * Gutenbergブロックを登録する
 */
function my_openai_theme_register_blocks() {
	// ブロックエディタのスクリプトが登録されているかチェック
	if (!function_exists('register_block_type')) {
		return;
	}

	// ボタンブロック用のスクリプト登録
	wp_register_script(
		'my-openai-button-block',
		get_stylesheet_directory_uri() . '/assets/js/openai-button-block.js',
		array('wp-blocks', 'wp-element', 'wp-editor', 'wp-components', 'wp-block-editor'),
		filemtime(get_stylesheet_directory() . '/assets/js/openai-button-block.js')
	);

	// ボタンブロックを登録
	register_block_type('my-openai-theme/button', array(
		'editor_script' => 'my-openai-button-block',
		'editor_style'  => 'my-openai-theme', // メインスタイルを使用
		'attributes'    => array(
			'buttonText' => array(
				'type' => 'string',
				'default' => 'ボタンテキスト',
			),
			'buttonUrl' => array(
				'type' => 'string',
				'default' => '',
			),
			'buttonStyle' => array(
				'type' => 'string',
				'default' => 'standard',
			),
			'buttonSize' => array(
				'type' => 'string',
				'default' => 'medium',
			),
			'backgroundColor' => array(
				'type' => 'string',
				'default' => '',
			),
			'hoverColor' => array(
				'type' => 'string',
				'default' => '',
			),
			'borderRadius' => array(
				'type' => 'number',
				'default' => 8,
			),
			'buttonWidth' => array(
				'type' => 'string',
				'default' => '',
			),
			'buttonPadding' => array(
				'type' => 'number',
				'default' => 0,
			),
			'openInNewTab' => array(
				'type' => 'boolean',
				'default' => false,
			),
			'align' => array(
				'type' => 'string',
				'default' => 'center',
			),
		),
		'render_callback' => 'my_openai_button_render_block',
	));

	// YouTubeブロック用のスクリプトとスタイルを登録
	wp_register_script(
		'my-openai-youtube-block',
		get_stylesheet_directory_uri() . '/assets/js/openai-youtube-block.js',
		array('wp-blocks', 'wp-element', 'wp-editor', 'wp-components', 'wp-block-editor'),
		filemtime(get_stylesheet_directory() . '/assets/js/openai-youtube-block.js')
	);

	// YouTubeブロックを登録
	register_block_type('my-openai-theme/youtube-embed', array(
		'editor_script' => 'my-openai-youtube-block',
		'editor_style'  => 'my-openai-theme', // メインスタイルを使用
		'attributes'    => array(
			'videoId' => array(
				'type' => 'string',
				'default' => '',
			),
			'title' => array(
				'type' => 'string',
				'default' => '',
			),
		),
		'render_callback' => 'my_openai_youtube_render_block',
	));
}
add_action('init', 'my_openai_theme_register_blocks');

/**
 * ボタンブロックをレンダリングする関数
 */
function my_openai_button_render_block($attributes) {
	$button_text = isset($attributes['buttonText']) ? esc_html($attributes['buttonText']) : 'ボタンテキスト';
	$button_url = isset($attributes['buttonUrl']) && !empty($attributes['buttonUrl']) ? esc_url($attributes['buttonUrl']) : 'javascript:void(0)';
	$button_style = isset($attributes['buttonStyle']) ? sanitize_html_class($attributes['buttonStyle']) : 'standard';
	$button_size = isset($attributes['buttonSize']) ? sanitize_html_class($attributes['buttonSize']) : 'medium';
	$background_color = isset($attributes['backgroundColor']) ? $attributes['backgroundColor'] : '';
	$hover_color = isset($attributes['hoverColor']) ? $attributes['hoverColor'] : '';
	$border_radius = isset($attributes['borderRadius']) ? intval($attributes['borderRadius']) : 8;
	$button_width = isset($attributes['buttonWidth']) ? $attributes['buttonWidth'] : '';
	$button_padding = isset($attributes['buttonPadding']) ? intval($attributes['buttonPadding']) : 0;
	$open_in_new_tab = isset($attributes['openInNewTab']) && $attributes['openInNewTab'] ? true : false;
	$align = isset($attributes['align']) ? sanitize_html_class($attributes['align']) : 'center';
	
	// スタイルに応じたクラス名を生成
	$button_class = 'openai-button';
	if ($button_style === 'pill') {
		$button_class .= ' openai-button-pill';
	} elseif ($button_style === 'ghost') {
		$button_class .= ' openai-button-ghost';
	}
	
	// サイズに応じたクラス名を追加
	$button_class .= ' openai-button-' . $button_size;
	
	// 追加の属性
	$target_attr = $open_in_new_tab ? ' target="_blank" rel="noopener noreferrer"' : '';
	$onclick_attr = ($button_url === 'javascript:void(0)') ? ' onclick="event.preventDefault()"' : '';
	$hover_attr = !empty($hover_color) ? ' data-hover-color="' . esc_attr($hover_color) . '"' : '';
	
	// コンテナスタイル
	$container_style = 'text-align: ' . esc_attr($align) . ';';
	if (!empty($button_width)) {
		$container_style .= ' width: 100%;';
	}
	
	// ボタンスタイルの組み立て
	$style_arr = array();
	
	// 背景色・文字色
	if (!empty($background_color)) {
		if ($button_style !== 'ghost') {
			$style_arr[] = 'background-color: ' . esc_attr($background_color);
			
			// 明るい色かどうかを判定
			if (is_light_color($background_color)) {
				$style_arr[] = 'color: #202123';
			}
		} else {
			$style_arr[] = 'border-color: ' . esc_attr($background_color);
			$style_arr[] = 'color: ' . esc_attr($background_color);
		}
	}
	
	// 角丸の調整
	if ($border_radius !== 8) {
		if ($button_style === 'pill') {
			// 丸型の場合は最低値を確保
			$style_arr[] = 'border-radius: ' . max(20, $border_radius) . 'px';
		} else {
			$style_arr[] = 'border-radius: ' . $border_radius . 'px';
		}
	}
	
	// 幅の設定
	if (!empty($button_width)) {
		$style_arr[] = 'width: ' . esc_attr($button_width);
		$style_arr[] = 'display: inline-block';
	}
	
	// パディングの調整
	if ($button_padding !== 0) {
		$base_padding = array();
		if ($button_size === 'small') {
			$base_padding = array(8, 16);
		} elseif ($button_size === 'medium') {
			$base_padding = array(10, 24);
		} else {
			$base_padding = array(12, 32);
		}
		
		$style_arr[] = 'padding: ' . ($base_padding[0] + $button_padding) . 'px ' . ($base_padding[1] + $button_padding) . 'px';
	}
	
	// スタイル属性の組み立て
	$style_attr = !empty($style_arr) ? ' style="' . implode('; ', $style_arr) . ';"' : '';
	
	$output = sprintf(
		'<div style="%s" class="openai-button-container"><a href="%s" class="%s"%s%s%s%s>%s</a></div>',
		$container_style,
		$button_url,
		esc_attr($button_class),
		$target_attr,
		$onclick_attr,
		$hover_attr,
		$style_attr,
		esc_html($button_text)
	);
	
	return $output;
}

/**
 * 明るい色かどうかを判定する関数
 */
function is_light_color($hex_color) {
	if (empty($hex_color)) {
		return false;
	}
	
	// #を取り除く
	$hex_color = ltrim($hex_color, '#');
	
	// 16進数の色コードをRGBに変換
	if (strlen($hex_color) === 3) {
		$r = hexdec(substr($hex_color, 0, 1) . substr($hex_color, 0, 1));
		$g = hexdec(substr($hex_color, 1, 1) . substr($hex_color, 1, 1));
		$b = hexdec(substr($hex_color, 2, 1) . substr($hex_color, 2, 1));
	} else {
		$r = hexdec(substr($hex_color, 0, 2));
		$g = hexdec(substr($hex_color, 2, 2));
		$b = hexdec(substr($hex_color, 4, 2));
	}
	
	// 明るさの計算（YIQ式）
	$yiq = (($r * 299) + ($g * 587) + ($b * 114)) / 1000;
	return $yiq >= 128; // 128以上なら明るい色
}

/**
 * YouTubeブロックをレンダリングする関数
 */
function my_openai_youtube_render_block($attributes) {
	$video_id = isset($attributes['videoId']) ? esc_attr($attributes['videoId']) : '';
	$title = isset($attributes['title']) ? esc_html($attributes['title']) : '';
	
	if (empty($video_id)) {
		return '<p class="error">YouTube動画IDが指定されていません。</p>';
	}
	
	$title_html = '';
	if (!empty($title)) {
		$title_html = '<div class="openai-youtube-title">' . $title . '</div>';
	}
	
	return '
	<div class="openai-youtube-container">
		<div class="openai-youtube-wrapper">
			<iframe width="560" height="315" src="https://www.youtube.com/embed/' . $video_id . '" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
		</div>
		' . $title_html . '
	</div>';
}

/**
 * YouTubeビデオ埋め込み用のショートコード
 * 
 * 使用例: [openai_youtube id="VIDEO_ID" title="動画タイトル"]
 */
function my_openai_youtube_shortcode( $atts ) {
    $atts = shortcode_atts( array(
        'id'    => '',
        'title' => '',
    ), $atts, 'openai_youtube' );
    
    if ( empty( $atts['id'] ) ) {
        return '<p class="error">YouTube動画IDを指定してください。</p>';
    }
    
    $video_id = esc_attr( $atts['id'] );
    $title = ! empty( $atts['title'] ) ? esc_html( $atts['title'] ) : '';
    
    $title_html = '';
    if ( ! empty( $title ) ) {
        $title_html = '<div class="openai-youtube-title">' . $title . '</div>';
    }
    
    return '
    <div class="openai-youtube-container">
        <div class="openai-youtube-wrapper">
            <iframe width="560" height="315" src="https://www.youtube.com/embed/' . $video_id . '" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
        </div>
        ' . $title_html . '
    </div>';
}
add_shortcode( 'openai_youtube', 'my_openai_youtube_shortcode' );

/**
 * OpenAIスタイルのヘッダーカスタマイズ機能を追加
 */
function my_openai_style_header_customizer($wp_customize) {
    // OpenAIヘッダースタイルセクション
    $wp_customize->add_section('openai_style_header_section', array(
        'title'    => 'OpenAIスタイル ヘッダー',
        'priority' => 20,
    ));
    
    // ヘッダースタイル選択
    $wp_customize->add_setting('openai_header_style', array(
        'default'           => 'default',
        'sanitize_callback' => 'sanitize_text_field',
    ));
    
    $wp_customize->add_control('openai_header_style', array(
        'label'    => 'ヘッダースタイル',
        'section'  => 'openai_style_header_section',
        'type'     => 'select',
        'choices'  => array(
            'default'     => '標準スタイル',
            'openai_dark' => 'OpenAI ダーク',
            'openai_light' => 'OpenAI ライト',
            'openai_transparent' => 'OpenAI 透過',
        ),
    ));
    
    // ヘッダー高さ（PC）
    $wp_customize->add_setting('openai_header_height_pc', array(
        'default'           => '80',
        'sanitize_callback' => 'absint',
    ));
    
    $wp_customize->add_control('openai_header_height_pc', array(
        'label'       => 'ヘッダーの高さ (PC)',
        'description' => 'px単位（60〜120px）',
        'section'     => 'openai_style_header_section',
        'type'        => 'number',
        'input_attrs' => array(
            'min'  => 60,
            'max'  => 120,
            'step' => 1,
        ),
    ));
    
    // ヘッダー高さ（SP）
    $wp_customize->add_setting('openai_header_height_sp', array(
        'default'           => '60',
        'sanitize_callback' => 'absint',
    ));
    
    $wp_customize->add_control('openai_header_height_sp', array(
        'label'       => 'ヘッダーの高さ (SP)',
        'description' => 'px単位（48〜80px）',
        'section'     => 'openai_style_header_section',
        'type'        => 'number',
        'input_attrs' => array(
            'min'  => 48,
            'max'  => 80,
            'step' => 1,
        ),
    ));
    
    // メニュー項目間隔
    $wp_customize->add_setting('openai_menu_spacing', array(
        'default'           => '16',
        'sanitize_callback' => 'absint',
    ));
    
    $wp_customize->add_control('openai_menu_spacing', array(
        'label'       => 'メニュー項目の間隔',
        'description' => 'px単位（8〜32px）',
        'section'     => 'openai_style_header_section',
        'type'        => 'number',
        'input_attrs' => array(
            'min'  => 8,
            'max'  => 32,
            'step' => 1,
        ),
    ));
    
    // メニューフォントサイズ
    $wp_customize->add_setting('openai_menu_font_size', array(
        'default'           => '16',
        'sanitize_callback' => 'absint',
    ));
    
    $wp_customize->add_control('openai_menu_font_size', array(
        'label'       => 'メニューフォントサイズ',
        'description' => 'px単位（14〜20px）',
        'section'     => 'openai_style_header_section',
        'type'        => 'number',
        'input_attrs' => array(
            'min'  => 14,
            'max'  => 20,
            'step' => 1,
        ),
    ));
    
    // ヘッダー背景色
    $wp_customize->add_setting('openai_header_bg_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'openai_header_bg_color', array(
        'label'    => 'ヘッダー背景色',
        'section'  => 'openai_style_header_section',
    )));
    
    // ヘッダーテキスト色
    $wp_customize->add_setting('openai_header_text_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'openai_header_text_color', array(
        'label'    => 'ヘッダーテキスト色',
        'section'  => 'openai_style_header_section',
    )));
    
    // ドロワーメニュー背景色
    $wp_customize->add_setting('openai_drawer_bg_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'openai_drawer_bg_color', array(
        'label'    => 'ドロワーメニュー背景色',
        'section'  => 'openai_style_header_section',
    )));
    
    // ロゴパディング
    $wp_customize->add_setting('openai_logo_padding', array(
        'default'           => '0',
        'sanitize_callback' => 'absint',
    ));
    
    $wp_customize->add_control('openai_logo_padding', array(
        'label'       => 'ロゴパディング',
        'description' => 'px単位（0〜20px）',
        'section'     => 'openai_style_header_section',
        'type'        => 'number',
        'input_attrs' => array(
            'min'  => 0,
            'max'  => 20,
            'step' => 1,
        ),
    ));
    
    // ボタン表示
    $wp_customize->add_setting('openai_show_header_button', array(
        'default'           => false,
        'sanitize_callback' => 'sanitize_bool',
    ));
    
    $wp_customize->add_control('openai_show_header_button', array(
        'label'    => 'アクションボタンを表示',
        'section'  => 'openai_style_header_section',
        'type'     => 'checkbox',
    ));
    
    // ボタンテキスト
    $wp_customize->add_setting('openai_header_button_text', array(
        'default'           => 'ログイン',
        'sanitize_callback' => 'sanitize_text_field',
    ));
    
    $wp_customize->add_control('openai_header_button_text', array(
        'label'    => 'ボタンテキスト',
        'section'  => 'openai_style_header_section',
        'type'     => 'text',
        'active_callback' => function() {
            return get_theme_mod('openai_show_header_button', false);
        },
    ));
    
    // ボタンURL
    $wp_customize->add_setting('openai_header_button_url', array(
        'default'           => '#',
        'sanitize_callback' => 'esc_url_raw',
    ));
    
    $wp_customize->add_control('openai_header_button_url', array(
        'label'    => 'ボタンURL',
        'section'  => 'openai_style_header_section',
        'type'     => 'url',
        'active_callback' => function() {
            return get_theme_mod('openai_show_header_button', false);
        },
    ));
    
    // ボタンスタイル
    $wp_customize->add_setting('openai_header_button_style', array(
        'default'           => 'filled',
        'sanitize_callback' => 'sanitize_text_field',
    ));
    
    $wp_customize->add_control('openai_header_button_style', array(
        'label'    => 'ボタンスタイル',
        'section'  => 'openai_style_header_section',
        'type'     => 'select',
        'choices'  => array(
            'filled' => '塗りつぶし',
            'outline' => '枠線のみ',
        ),
        'active_callback' => function() {
            return get_theme_mod('openai_show_header_button', false);
        },
    ));
}
add_action('customize_register', 'my_openai_style_header_customizer');

/**
 * カスタマイザーで設定したOpenAIスタイルヘッダーのCSSを出力
 */
function my_openai_style_header_css() {
    $header_style = get_theme_mod('openai_header_style', 'default');
    
    // デフォルトスタイルの場合は何もしない
    if ($header_style === 'default') {
        return;
    }
    
    $header_height_pc = get_theme_mod('openai_header_height_pc', '80');
    $header_height_sp = get_theme_mod('openai_header_height_sp', '60');
    $menu_spacing = get_theme_mod('openai_menu_spacing', '16');
    $menu_font_size = get_theme_mod('openai_menu_font_size', '16');
    $logo_padding = get_theme_mod('openai_logo_padding', '0');
    
    $header_bg_color = get_theme_mod('openai_header_bg_color', '');
    $header_text_color = get_theme_mod('openai_header_text_color', '');
    $drawer_bg_color = get_theme_mod('openai_drawer_bg_color', '');
    
    // OpenAIスタイルに応じたデフォルトの色設定
    if (empty($header_bg_color)) {
        switch ($header_style) {
            case 'openai_dark':
                $header_bg_color = '#0f0f0f';
                break;
            case 'openai_light':
                $header_bg_color = '#ffffff';
                break;
            case 'openai_transparent':
                $header_bg_color = 'transparent';
                break;
        }
    }
    
    if (empty($header_text_color)) {
        switch ($header_style) {
            case 'openai_dark':
                $header_text_color = '#ffffff';
                break;
            case 'openai_light':
                $header_text_color = '#202123';
                break;
            case 'openai_transparent':
                $header_text_color = '#ffffff';
                break;
        }
    }
    
    if (empty($drawer_bg_color)) {
        $drawer_bg_color = ($header_style === 'openai_light') ? '#f7f7f7' : '#0f0f0f';
    }
    
    // スクロール時の背景色を定義
    $scrolled_bg_color = $header_bg_color;
    if ($header_style === 'openai_transparent') {
        $scrolled_bg_color = '#0f0f0f';
    }
    
    // 透過モードでホームページのときに特別な設定を適用
    $top_hero_styles = '';
    if ($header_style === 'openai_transparent' && is_front_page()) {
        $top_hero_styles = "
            /* トップページのヒーロースタイル（OpenAI風） */
            .p-mainVisual {
                margin-top: -${header_height_pc}px !important;
                padding-top: ${header_height_pc}px !important;
                min-height: 80vh !important;
                position: relative;
                z-index: 0;
            }
            
            .p-mainVisual::before {
                content: '';
                position: absolute;
                top: 0;
                left: 0;
                width: 100%;
                height: 100%;
                background: linear-gradient(to bottom, rgba(0,0,0,0.7) 0%, rgba(0,0,0,0.3) 40%, rgba(0,0,0,0) 100%);
                z-index: -1;
            }
            
            @media (max-width: 959px) {
                .p-mainVisual {
                    margin-top: -${header_height_sp}px !important;
                    padding-top: ${header_height_sp}px !important;
                }
            }
        ";
    }
    
    // ヘッダースタイルのCSS生成
    $css = "
        /* OpenAIスタイルヘッダーカスタマイズ */
        .l-header {
            height: {$header_height_pc}px !important;
            background-color: {$header_bg_color} !important;
            color: {$header_text_color} !important;
            transition: background-color 0.3s ease, height 0.3s ease, box-shadow 0.3s ease !important;
            border-bottom: none !important;
            " . ($header_style === 'openai_transparent' ? 'position: absolute; width: 100%; z-index: 100;' : '') . "
        }
        
        .l-header a {
            color: {$header_text_color} !important;
        }
        
        .c-headLogo {
            padding: {$logo_padding}px !important;
        }
        
        .c-gnavList > li {
            margin-left: {$menu_spacing}px !important;
        }
        
        .c-gnavList > li > a {
            font-size: {$menu_font_size}px !important;
            font-weight: 500 !important;
            position: relative;
            transition: opacity 0.3s ease;
        }
        
        .c-gnavList > li > a:hover {
            opacity: 0.7;
        }
        
        .c-gnavList > li > a::after {
            content: '';
            position: absolute;
            bottom: -4px;
            left: 0;
            width: 0;
            height: 2px;
            background-color: {$header_text_color};
            transition: width 0.3s ease;
        }
        
        .c-gnavList > li > a:hover::after {
            width: 100%;
        }
        
        .c-drawerMenu {
            background-color: {$drawer_bg_color} !important;
        }
        
        /* スクロール時の変化（OpenAI風） */
        html[data-scrolled='true'] .l-header {
            height: " . ($header_height_pc - 10) . "px !important;
            background-color: {$scrolled_bg_color} !important;
            box-shadow: 0 2px 10px rgba(0, 0, 0, " . ($header_style === 'openai_light' ? '0.05' : '0.15') . ") !important;
            " . ($header_style === 'openai_transparent' ? 'position: fixed; top: 0;' : '') . "
        }
        
        /* レスポンシブ対応 */
        @media (max-width: 959px) {
            .l-header {
                height: {$header_height_sp}px !important;
            }
            
            html[data-scrolled='true'] .l-header {
                height: " . ($header_height_sp - 5) . "px !important;
            }
            
            .c-iconBtn {
                color: {$header_text_color} !important;
            }
        }
        
        {$top_hero_styles}
    ";
    
    // ボタン表示の場合はボタンスタイルも追加
    if (get_theme_mod('openai_show_header_button', false)) {
        $button_style = get_theme_mod('openai_header_button_style', 'filled');
        
        if ($button_style === 'filled') {
            $css .= "
                .l-header__right::after {
                    content: '" . esc_attr(get_theme_mod('openai_header_button_text', 'ログイン')) . "';
                    display: inline-block;
                    padding: 8px 16px;
                    margin-left: 16px;
                    background-color: " . ($header_style === 'openai_light' ? '#202123' : '#ffffff') . ";
                    color: " . ($header_style === 'openai_light' ? '#ffffff' : '#202123') . " !important;
                    border-radius: 4px;
                    font-weight: 500;
                    cursor: pointer;
                    transition: all 0.3s;
                }
                
                .l-header__right::after:hover {
                    opacity: 0.9;
                }
            ";
        } else {
            $css .= "
                .l-header__right::after {
                    content: '" . esc_attr(get_theme_mod('openai_header_button_text', 'ログイン')) . "';
                    display: inline-block;
                    padding: 7px 15px;
                    margin-left: 16px;
                    background-color: transparent;
                    color: {$header_text_color} !important;
                    border: 1px solid {$header_text_color};
                    border-radius: 4px;
                    font-weight: 500;
                    cursor: pointer;
                    transition: all 0.3s;
                }
                
                .l-header__right::after:hover {
                    background-color: {$header_text_color};
                    color: {$header_bg_color} !important;
                }
            ";
        }
    }
    
    echo '<style id="openai-style-header-css">' . $css . '</style>';
}
add_action('wp_head', 'my_openai_style_header_css');

/**
 * Boolean値のサニタイズ
 */
function sanitize_bool($input) {
    return (bool) $input;
}

/**
 * カスタマイザーの設定に基づいて、ヘッダーボタンにJavaScriptを適用する
 */
function my_openai_style_header_scripts() {
    // ボタンが有効でない場合は処理しない
    if (!get_theme_mod('openai_show_header_button', false)) {
        return;
    }
    
    $button_url = get_theme_mod('openai_header_button_url', '#');
    
    // ボタンクリック時の動作を定義するJavaScript
    ?>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
        // ヘッダー右側の要素を取得
        var headerRight = document.querySelector('.l-header__right');
        if (!headerRight) return;
        
        // ボタンクリック時の処理を追加
        headerRight.addEventListener('click', function(e) {
            // ::afterに対するクリックイベントを検出（疑似要素自体は取得できないため親要素で判定）
            var rect = headerRight.getBoundingClientRect();
            var x = e.clientX - rect.left;
            var width = rect.width;
            
            // 右側の領域（ボタンの疑似要素）をクリックした場合
            if (x > (width - 100)) {
                window.location.href = '<?php echo esc_js($button_url); ?>';
            }
        });
    });
    </script>
    <?php
}
add_action('wp_footer', 'my_openai_style_header_scripts');

/**
 * Heroセクション用ブロックパターンの登録
 */
function my_openai_register_hero_pattern() {
    register_block_pattern(
        'my-openai-theme/hero-center-cover',
        array(
            'title'       => __( 'Hero - 中央揃え (Coverベース)', 'my-openai-theme' ),
            'description' => __( '背景画像/動画を持つカスタマイズ可能なHeroセクション', 'my-openai-theme' ),
            'categories'  => array( 'hero', 'openai-patterns' ),
            'keywords'    => array( 'hero', 'cover', 'openai', 'main visual' ),
            'blockTypes'  => array( 'core/cover' ),
            'viewportWidth' => 1200,
            'content'     => '<!-- wp:cover {"overlayColor":"black","minHeight":75,"minHeightUnit":"vh","align":"full","className":"is-style-openai-hero-dark"} -->
<div class="wp-block-cover alignfull is-style-openai-hero-dark" style="min-height:75vh">
<span aria-hidden="true" class="wp-block-cover__background has-black-background-color has-background-dim-50 wp-block-cover__gradient-background has-background-dim"></span>
<div class="wp-block-cover__inner-container">
<!-- wp:group {"layout":{"type":"constrained"}} -->
<div class="wp-block-group">
<!-- wp:heading {"textAlign":"center","level":1,"style":{"typography":{"fontSize":"clamp(3.6rem, 6vw, 5.6rem)","lineHeight":"1.2"}},"textColor":"white","className":"wow u-fade-in u-fade-in-delay-1"} -->
<h1 class="wp-block-heading has-text-align-center has-white-color has-text-color wow u-fade-in u-fade-in-delay-1" style="font-size:clamp(3.6rem, 6vw, 5.6rem);line-height:1.2">ここにキャッチコピーを入力</h1>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","style":{"typography":{"fontSize":"1.125rem"}},"textColor":"white","className":"wow u-fade-in u-fade-in-delay-2"} -->
<p class="has-text-align-center has-white-color has-text-color wow u-fade-in u-fade-in-delay-2" style="font-size:1.125rem">この下にリード文や説明を追加します。背景画像や色はCoverブロックの設定から変更できます。</p>
<!-- /wp:paragraph -->

<!-- wp:spacer {"height":"20px"} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"layout":{"type":"flex","justifyContent":"center"},"className":"wow u-fade-in u-fade-in-delay-3"} -->
<div class="wp-block-buttons wow u-fade-in u-fade-in-delay-3">
<!-- wp:button {"backgroundColor":"white","textColor":"black","className":"is-style-openai-button u-lift"} -->
<div class="wp-block-button is-style-openai-button u-lift"><a class="wp-block-button__link has-black-color has-white-background-color has-text-color has-background wp-element-button">詳細を見る</a></div>
<!-- /wp:button -->
</div>
<!-- /wp:buttons -->
</div>
<!-- /wp:group -->
</div>
</div>
<!-- /wp:cover -->',
        )
    );
    
    // パターンカテゴリー登録（もし未登録なら）
    if (function_exists('register_block_pattern_category')) {
        register_block_pattern_category(
            'hero',
            array( 'label' => __( 'Hero Sections', 'my-openai-theme' ) )
        );
    }
}
add_action( 'init', 'my_openai_register_hero_pattern' );

/**
 * core/cover ブロックにOpenAI風スタイルバリエーションを追加
 */
function my_openai_register_cover_block_styles() {
    register_block_style(
        'core/cover',
        array(
            'name'         => 'openai-hero-dark',
            'label'        => __( 'OpenAI Hero (ダーク)', 'my-openai-theme' ),
            // style_handle で特定のCSSを紐付け可能だが、今回は汎用クラスで対応
            'inline_style' => '.is-style-openai-hero-dark.wp-block-cover .wp-block-cover__background { background-color: #000000; opacity: 0.6 !important; } .is-style-openai-hero-dark.wp-block-cover .wp-block-cover__inner-container { color: #ffffff; }',
            'is_default'   => true,
        )
    );

    register_block_style(
        'core/cover',
        array(
            'name'         => 'openai-hero-light',
            'label'        => __( 'OpenAI Hero (ライト)', 'my-openai-theme' ),
            'inline_style' => '.is-style-openai-hero-light.wp-block-cover .wp-block-cover__background { background-color: #ffffff; opacity: 0.2 !important; } .is-style-openai-hero-light.wp-block-cover .wp-block-cover__inner-container { color: #202123; } .is-style-openai-hero-light .has-white-color { color: #202123 !important; }',
        )
    );
    
    register_block_style(
        'core/cover',
        array(
            'name'         => 'openai-hero-gradient',
            'label'        => __( 'OpenAI Hero (グラデーション)', 'my-openai-theme' ),
            'inline_style' => '.is-style-openai-hero-gradient.wp-block-cover .wp-block-cover__background { background: linear-gradient(135deg, rgba(0,122,255,0.7) 0%, rgba(0,82,173,0.8) 100%); opacity: 1 !important; } .is-style-openai-hero-gradient.wp-block-cover .wp-block-cover__inner-container { color: #ffffff; }',
        )
    );
}
add_action( 'init', 'my_openai_register_cover_block_styles' );

/**
 * Heroセクション用ユーティリティCSSとインタラクションJSの追加
 */
function my_openai_hero_assets() {
    // ユーティリティCSS
    $utility_css = "
        .u-fade-in {
            opacity: 0;
            transform: translateY(20px);
            transition: opacity 0.8s ease-out, transform 0.8s ease-out;
        }
        .u-fade-in.is-visible {
            opacity: 1;
            transform: translateY(0);
        }
        .u-fade-in-delay-1 { transition-delay: 0.1s; }
        .u-fade-in-delay-2 { transition-delay: 0.2s; }
        .u-fade-in-delay-3 { transition-delay: 0.3s; }
        
        .u-lift {
            transition: transform 0.3s ease, box-shadow 0.3s ease;
        }
        .u-lift:hover {
            transform: translateY(-4px);
            box-shadow: 0 10px 20px rgba(0,0,0,0.1);
        }
        
        /* Coverブロックのデフォルトスタイル調整 */
        .wp-block-cover .wp-block-cover__inner-container {
            width: calc(100% - 60px); /* 左右に少し余白 */
            max-width: 1100px; /* 最大幅 */
            z-index: 1; /* テキストが背景より手前に来るように */
        }
        
        /* ボタンにスタイルを適用 */
        .wp-block-cover .wp-block-button.is-style-openai-button a {
            background-color: #ffffff;
            color: #000000 !important; /* 重要な場合 */
            padding: 12px 28px;
            font-weight: 600;
            border-radius: 8px;
        }
        .is-style-openai-hero-light .wp-block-cover .wp-block-button.is-style-openai-button a {
             background-color: #000000;
            color: #ffffff !important;
        }
    ";
    wp_add_inline_style( 'arkhe-main-style', $utility_css ); // ArkheのメインCSSにインラインで追加

    // インタラクションJS
    $interaction_js = "
    document.addEventListener('DOMContentLoaded', function() {
        const fadeInElements = document.querySelectorAll('.u-fade-in');
        
        if ('IntersectionObserver' in window) {
            const observer = new IntersectionObserver((entries, observer) => {
                entries.forEach(entry => {
                    if (entry.isIntersecting) {
                        entry.target.classList.add('is-visible');
                        observer.unobserve(entry.target);
                    }
                });
            }, { threshold: 0.1 }); // 10%表示されたら発火

            fadeInElements.forEach(el => {
                observer.observe(el);
            });
        } else {
            // IntersectionObserver非対応ブラウザ向けのフォールバック
            fadeInElements.forEach(el => {
                el.classList.add('is-visible');
            });
        }
    });
    ";
    wp_add_inline_script( 'arkhe-main-script', $interaction_js ); // ArkheのメインJSにインラインで追加
}
add_action( 'wp_enqueue_scripts', 'my_openai_hero_assets' );

/**
 * Heroセクション用の追加カスタマイザー設定
 */
function my_openai_hero_customizer_settings($wp_customize) {
    // セクションを追加
    $wp_customize->add_section( 'openai_hero_section', array(
        'title'    => 'Heroセクション (OpenAI Style)',
        'priority' => 90,
        'description' => 'OpenAIスタイルのHeroセクションの設定です。設定を適用するには、フロントページでOpenAI Heroブロックパターンを使用してください。',
    ) );

    // 基本設定
    $wp_customize->add_setting( 'openai_hero_min_height_vh', array(
        'default'           => '75',
        'sanitize_callback' => 'absint',
    ) );
    $wp_customize->add_control( 'openai_hero_min_height_vh', array(
        'label'    => '最小高さ (vh)',
        'section'  => 'openai_hero_section',
        'type'     => 'range',
        'input_attrs' => array(
            'min'  => 40,
            'max'  => 100,
            'step' => 5,
        ),
    ) );

    $wp_customize->add_setting( 'openai_hero_overlay_color', array(
        'default'           => '#000000',
        'sanitize_callback' => 'sanitize_hex_color',
    ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'openai_hero_overlay_color', array(
        'label'    => '重ね色',
        'section'  => 'openai_hero_section',
    ) ) );

    $wp_customize->add_setting( 'openai_hero_overlay_opacity', array(
        'default'           => '0.5',
        'sanitize_callback' => 'my_openai_sanitize_decimal',
    ) );
    $wp_customize->add_control( 'openai_hero_overlay_opacity', array(
        'label'    => '重ね色の不透明度',
        'section'  => 'openai_hero_section',
        'type'     => 'range',
        'input_attrs' => array(
            'min'  => 0,
            'max'  => 1,
            'step' => 0.05,
        ),
    ) );

    $wp_customize->add_setting( 'openai_hero_border_radius', array(
        'default'           => '0',
        'sanitize_callback' => 'absint',
    ) );
    $wp_customize->add_control( 'openai_hero_border_radius', array(
        'label'    => '角丸 (px)',
        'section'  => 'openai_hero_section',
        'type'     => 'range',
        'input_attrs' => array(
            'min'  => 0,
            'max'  => 50,
            'step' => 2,
        ),
    ) );

    // 内部コンテナのパディング設定
    $padding_positions = array(
        'top'    => '上',
        'right'  => '右',
        'bottom' => '下',
        'left'   => '左'
    );

    foreach ( $padding_positions as $pos => $label ) {
        $wp_customize->add_setting( 'openai_hero_inner_padding_' . $pos, array(
            'default'           => '30',
            'sanitize_callback' => 'absint',
        ) );
        $wp_customize->add_control( 'openai_hero_inner_padding_' . $pos, array(
            'label'    => '内部パディング' . $label . ' (px)',
            'section'  => 'openai_hero_section',
            'type'     => 'number',
        ) );
    }

    // テキスト設定
    $wp_customize->add_setting( 'openai_hero_heading_font_size_pc', array(
        'default'           => '48',
        'sanitize_callback' => 'absint',
    ) );
    $wp_customize->add_control( 'openai_hero_heading_font_size_pc', array(
        'label'    => '見出しフォントサイズ (PC) (px)',
        'section'  => 'openai_hero_section',
        'type'     => 'range',
        'input_attrs' => array(
            'min'  => 20,
            'max'  => 80,
            'step' => 2,
        ),
    ) );
    
    $wp_customize->add_setting( 'openai_hero_heading_font_size_sp', array(
        'default'           => '28',
        'sanitize_callback' => 'absint',
    ) );
    $wp_customize->add_control( 'openai_hero_heading_font_size_sp', array(
        'label'    => '見出しフォントサイズ (SP) (px)',
        'section'  => 'openai_hero_section',
        'type'     => 'range',
        'input_attrs' => array(
            'min'  => 16,
            'max'  => 42,
            'step' => 2,
        ),
    ) );
    
    $wp_customize->add_setting( 'openai_hero_heading_font_weight', array(
        'default'           => '700',
        'sanitize_callback' => 'absint',
    ) );
    $wp_customize->add_control( 'openai_hero_heading_font_weight', array(
        'label'    => '見出しフォントウェイト',
        'section'  => 'openai_hero_section',
        'type'     => 'select',
        'choices'  => array(
            '400' => 'レギュラー (400)',
            '500' => 'ミディアム (500)',
            '600' => 'セミボールド (600)',
            '700' => 'ボールド (700)',
            '800' => 'エクストラボールド (800)'
        ),
    ) );
    
    $wp_customize->add_setting( 'openai_hero_heading_line_height', array(
        'default'           => '1.2',
        'sanitize_callback' => 'my_openai_sanitize_decimal',
    ) );
    $wp_customize->add_control( 'openai_hero_heading_line_height', array(
        'label'    => '見出し行の高さ',
        'section'  => 'openai_hero_section',
        'type'     => 'range',
        'input_attrs' => array(
            'min'  => 0.8,
            'max'  => 2,
            'step' => 0.1,
        ),
    ) );
    
    $wp_customize->add_setting( 'openai_hero_text_font_size_pc', array(
        'default'           => '18',
        'sanitize_callback' => 'absint',
    ) );
    $wp_customize->add_control( 'openai_hero_text_font_size_pc', array(
        'label'    => '本文フォントサイズ (PC) (px)',
        'section'  => 'openai_hero_section',
        'type'     => 'range',
        'input_attrs' => array(
            'min'  => 12,
            'max'  => 32,
            'step' => 1,
        ),
    ) );
    
    $wp_customize->add_setting( 'openai_hero_text_font_size_sp', array(
        'default'           => '14',
        'sanitize_callback' => 'absint',
    ) );
    $wp_customize->add_control( 'openai_hero_text_font_size_sp', array(
        'label'    => '本文フォントサイズ (SP) (px)',
        'section'  => 'openai_hero_section',
        'type'     => 'range',
        'input_attrs' => array(
            'min'  => 10,
            'max'  => 24,
            'step' => 1,
        ),
    ) );
    
    $wp_customize->add_setting( 'openai_hero_text_alignment', array(
        'default'           => 'center',
        'sanitize_callback' => 'sanitize_text_field',
    ) );
    $wp_customize->add_control( 'openai_hero_text_alignment', array(
        'label'    => 'テキスト配置（横方向）',
        'section'  => 'openai_hero_section',
        'type'     => 'select',
        'choices'  => array(
            'left'   => '左寄せ',
            'center' => '中央揃え',
            'right'  => '右寄せ'
        ),
    ) );
    
    // 垂直方向の配置設定を追加
    $wp_customize->add_setting( 'openai_hero_vertical_alignment', array(
        'default'           => 'center',
        'sanitize_callback' => 'sanitize_text_field',
    ) );
    $wp_customize->add_control( 'openai_hero_vertical_alignment', array(
        'label'    => 'テキスト配置（垂直方向）',
        'section'  => 'openai_hero_section',
        'type'     => 'select',
        'choices'  => array(
            'top'           => '上寄せ',
            'center'        => '中央揃え',
            'bottom'        => '下寄せ',
            'space-between' => '均等配置'
        ),
    ) );
    
    // アニメーション設定
    $wp_customize->add_setting( 'openai_hero_enable_animation', array(
        'default'           => true,
        'sanitize_callback' => 'my_openai_sanitize_checkbox',
    ) );
    $wp_customize->add_control( 'openai_hero_enable_animation', array(
        'label'    => 'アニメーションを有効化',
        'section'  => 'openai_hero_section',
        'type'     => 'checkbox',
    ) );
    
    $wp_customize->add_setting( 'openai_hero_animation_type', array(
        'default'           => 'fade-in',
        'sanitize_callback' => 'sanitize_text_field',
    ) );
    $wp_customize->add_control( 'openai_hero_animation_type', array(
        'label'    => 'アニメーション種類',
        'section'  => 'openai_hero_section',
        'type'     => 'select',
        'choices'  => array(
            'fade-in'    => 'フェードイン',
            'slide-up'   => '下から上へスライド',
            'slide-left' => '右から左へスライド',
            'slide-right' => '左から右へスライド',
            'zoom-in'    => 'ズームイン',
            'bounce'     => 'バウンス'
        ),
    ) );
    
    $wp_customize->add_setting( 'openai_hero_animation_speed', array(
        'default'           => '0.8',
        'sanitize_callback' => 'my_openai_sanitize_decimal',
    ) );
    $wp_customize->add_control( 'openai_hero_animation_speed', array(
        'label'    => 'アニメーション速度 (秒)',
        'section'  => 'openai_hero_section',
        'type'     => 'range',
        'input_attrs' => array(
            'min'  => 0.1,
            'max'  => 2,
            'step' => 0.1,
        ),
    ) );
    
    $wp_customize->add_setting( 'openai_hero_animation_delay_base', array(
        'default'           => '0.2',
        'sanitize_callback' => 'my_openai_sanitize_decimal',
    ) );
    $wp_customize->add_control( 'openai_hero_animation_delay_base', array(
        'label'    => 'アニメーション遅延 - 基本 (秒)',
        'section'  => 'openai_hero_section',
        'type'     => 'range',
        'input_attrs' => array(
            'min'  => 0,
            'max'  => 1,
            'step' => 0.1,
        ),
    ) );
    
    $wp_customize->add_setting( 'openai_hero_animation_delay_increment', array(
        'default'           => '0.2',
        'sanitize_callback' => 'my_openai_sanitize_decimal',
    ) );
    $wp_customize->add_control( 'openai_hero_animation_delay_increment', array(
        'label'    => 'アニメーション遅延 - 増分 (秒)',
        'section'  => 'openai_hero_section',
        'type'     => 'range',
        'input_attrs' => array(
            'min'  => 0.1,
            'max'  => 0.5,
            'step' => 0.05,
        ),
    ) );
    
    // ボタン設定
    $wp_customize->add_setting( 'openai_hero_button_bg_color', array(
        'default'           => '#3B82F6',
        'sanitize_callback' => 'sanitize_hex_color',
    ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'openai_hero_button_bg_color', array(
        'label'    => 'ボタン背景色',
        'section'  => 'openai_hero_section',
    ) ) );
    
    $wp_customize->add_setting( 'openai_hero_button_text_color', array(
        'default'           => '#FFFFFF',
        'sanitize_callback' => 'sanitize_hex_color',
    ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'openai_hero_button_text_color', array(
        'label'    => 'ボタンテキスト色',
        'section'  => 'openai_hero_section',
    ) ) );
    
    $wp_customize->add_setting( 'openai_hero_button_border_radius', array(
        'default'           => '8',
        'sanitize_callback' => 'absint',
    ) );
    $wp_customize->add_control( 'openai_hero_button_border_radius', array(
        'label'    => 'ボタン角丸 (px)',
        'section'  => 'openai_hero_section',
        'type'     => 'range',
        'input_attrs' => array(
            'min'  => 0,
            'max'  => 30,
            'step' => 1,
        ),
    ) );
    
    $wp_customize->add_setting( 'openai_hero_button_hover_effect', array(
        'default'           => 'lift',
        'sanitize_callback' => 'sanitize_text_field',
    ) );
    $wp_customize->add_control( 'openai_hero_button_hover_effect', array(
        'label'    => 'ボタンホバーエフェクト',
        'section'  => 'openai_hero_section',
        'type'     => 'select',
        'choices'  => array(
            'none'        => 'なし',
            'lift'        => '浮き上がり',
            'scale'       => '拡大',
            'shadow'      => '影付き',
            'color-shift' => '色変化'
        ),
    ) );
}
add_action( 'customize_register', 'my_openai_hero_customizer_settings' );

/**
 * 小数値のサニタイズ関数
 */
function my_openai_sanitize_decimal( $input ) {
    return filter_var( $input, FILTER_SANITIZE_NUMBER_FLOAT, FILTER_FLAG_ALLOW_FRACTION );
}

/**
 * チェックボックスのサニタイズ関数
 */
function my_openai_sanitize_checkbox( $checked ) {
    return ( ( isset( $checked ) && true == $checked ) ? true : false );
}

/**
 * Heroセクション (OpenAI Style) のカスタマイザー設定に基づいてCSSを出力
 */
function my_openai_hero_customizer_css() {
    $min_height_vh = get_theme_mod( 'openai_hero_min_height_vh', '75' );
    $overlay_color = get_theme_mod( 'openai_hero_overlay_color', '#000000' );
    $overlay_opacity = get_theme_mod( 'openai_hero_overlay_opacity', '0.5' );
    $border_radius = get_theme_mod( 'openai_hero_border_radius', '0' );
    
    // パディング設定
    $padding_top = get_theme_mod( 'openai_hero_inner_padding_top', '30' );
    $padding_right = get_theme_mod( 'openai_hero_inner_padding_right', '30' );
    $padding_bottom = get_theme_mod( 'openai_hero_inner_padding_bottom', '30' );
    $padding_left = get_theme_mod( 'openai_hero_inner_padding_left', '30' );
    
    // テキスト設定
    $heading_font_size_pc = get_theme_mod( 'openai_hero_heading_font_size_pc', '48' );
    $heading_font_size_sp = get_theme_mod( 'openai_hero_heading_font_size_sp', '28' );
    $heading_font_weight = get_theme_mod( 'openai_hero_heading_font_weight', '700' );
    $heading_line_height = get_theme_mod( 'openai_hero_heading_line_height', '1.2' );
    $text_font_size_pc = get_theme_mod( 'openai_hero_text_font_size_pc', '18' );
    $text_font_size_sp = get_theme_mod( 'openai_hero_text_font_size_sp', '14' );
    $text_alignment = get_theme_mod( 'openai_hero_text_alignment', 'center' );
    $vertical_alignment = get_theme_mod( 'openai_hero_vertical_alignment', 'center' );
    
    // アニメーション設定
    $enable_animation = get_theme_mod( 'openai_hero_enable_animation', true );
    $animation_type = get_theme_mod( 'openai_hero_animation_type', 'fade-in' );
    $animation_speed = get_theme_mod( 'openai_hero_animation_speed', '0.8' );
    $animation_delay_base = get_theme_mod( 'openai_hero_animation_delay_base', '0.2' );
    $animation_delay_increment = get_theme_mod( 'openai_hero_animation_delay_increment', '0.2' );
    
    // ボタン設定
    $button_bg_color = get_theme_mod( 'openai_hero_button_bg_color', '#3B82F6' );
    $button_text_color = get_theme_mod( 'openai_hero_button_text_color', '#FFFFFF' );
    $button_border_radius = get_theme_mod( 'openai_hero_button_border_radius', '8' );
    $button_hover_effect = get_theme_mod( 'openai_hero_button_hover_effect', 'lift' );
    
    // CSSを生成
    $css = "
        body.home .wp-block-cover.alignfull[class*=\"is-style-openai-hero-\"] {
            min-height: {$min_height_vh}vh;
            border-radius: {$border_radius}px;
        }
        
        body.home .wp-block-cover.alignfull[class*=\"is-style-openai-hero-\"] .wp-block-cover__background,
        body.home .wp-block-cover.alignfull[class*=\"is-style-openai-hero-\"] .wp-block-cover__gradient-background {
            background-color: {$overlay_color} !important;
            opacity: {$overlay_opacity} !important;
        }
        
        body.home .wp-block-cover.alignfull[class*=\"is-style-openai-hero-\"] .wp-block-cover__inner-container {
            padding: {$padding_top}px {$padding_right}px {$padding_bottom}px {$padding_left}px;
            text-align: {$text_alignment};
            display: flex;
            flex-direction: column;
    ";
    
    // 垂直方向の配置
    switch ( $vertical_alignment ) {
        case 'top':
            $css .= "justify-content: flex-start;";
            break;
        case 'center':
            $css .= "justify-content: center;";
            break;
        case 'bottom':
            $css .= "justify-content: flex-end;";
            break;
        case 'space-between':
            $css .= "justify-content: space-between;";
            break;
    }
    
    // 水平方向の配置に基づいてalign-itemsを設定
    switch ( $text_alignment ) {
        case 'left':
            $css .= "align-items: flex-start;";
            break;
        case 'center':
            $css .= "align-items: center;";
            break;
        case 'right':
            $css .= "align-items: flex-end;";
            break;
    }
    
    $css .= "
        }
        
        @media (min-width: 768px) {
            body.home .wp-block-cover.alignfull[class*=\"is-style-openai-hero-\"] h1,
            body.home .wp-block-cover.alignfull[class*=\"is-style-openai-hero-\"] h2 {
                font-size: {$heading_font_size_pc}px;
            }
            
            body.home .wp-block-cover.alignfull[class*=\"is-style-openai-hero-\"] p:not(.wp-block-cover-text) {
                font-size: {$text_font_size_pc}px;
            }
        }
        
        @media (max-width: 767px) {
            body.home .wp-block-cover.alignfull[class*=\"is-style-openai-hero-\"] h1,
            body.home .wp-block-cover.alignfull[class*=\"is-style-openai-hero-\"] h2 {
                font-size: {$heading_font_size_sp}px;
            }
            
            body.home .wp-block-cover.alignfull[class*=\"is-style-openai-hero-\"] p:not(.wp-block-cover-text) {
                font-size: {$text_font_size_sp}px;
            }
        }
        
        body.home .wp-block-cover.alignfull[class*=\"is-style-openai-hero-\"] h1,
        body.home .wp-block-cover.alignfull[class*=\"is-style-openai-hero-\"] h2 {
            font-weight: {$heading_font_weight};
            line-height: {$heading_line_height};
        }
        
        body.home .wp-block-cover.alignfull[class*=\"is-style-openai-hero-\"] .wp-block-button__link {
            background-color: {$button_bg_color} !important;
            color: {$button_text_color} !important;
            border-radius: {$button_border_radius}px !important;
        }
    ";
    
    // アニメーション設定
    if ( $enable_animation ) {
        $css .= "
            .u-fade-in {
                opacity: 0;
        ";
        
        // アニメーション種類別の初期状態
        switch ( $animation_type ) {
            case 'fade-in':
                $css .= "transform: translateY(20px);";
                break;
            case 'slide-up':
                $css .= "transform: translateY(50px);";
                break;
            case 'slide-left':
                $css .= "transform: translateX(50px);";
                break;
            case 'slide-right':
                $css .= "transform: translateX(-50px);";
                break;
            case 'zoom-in':
                $css .= "transform: scale(0.8);";
                break;
        }
        
        $css .= "
                transition: opacity {$animation_speed}s ease-out, transform {$animation_speed}s ease-out;
            }
            
            .u-fade-in.is-visible {
                opacity: 1;
                transform: none;
            }
            
            .u-fade-in-delay-1 {
                transition-delay: {$animation_delay_base}s;
            }
            
            .u-fade-in-delay-2 {
                transition-delay: " . (floatval($animation_delay_base) + floatval($animation_delay_increment)) . "s;
            }
            
            .u-fade-in-delay-3 {
                transition-delay: " . (floatval($animation_delay_base) + (floatval($animation_delay_increment) * 2)) . "s;
            }
        ";
        
        // バウンスアニメーション用のキーフレーム
        if ( $animation_type === 'bounce' ) {
            $css .= "
                @keyframes heroSectionBounce {
                    0%, 20%, 50%, 80%, 100% {
                        transform: translateY(0);
                    }
                    40% {
                        transform: translateY(-30px);
                    }
                    60% {
                        transform: translateY(-15px);
                    }
                }
                
                .u-fade-in.is-visible {
                    animation: heroSectionBounce {$animation_speed}s;
                }
            ";
        }
    }
    
    // ボタンホバーエフェクト
    switch ( $button_hover_effect ) {
        case 'lift':
            $css .= "
                .u-lift {
                    transition: transform 0.3s ease, box-shadow 0.3s ease;
                }
                .u-lift:hover {
                    transform: translateY(-5px);
                    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
                }
            ";
            break;
        case 'scale':
            $css .= "
                .u-lift {
                    transition: transform 0.3s ease;
                }
                .u-lift:hover {
                    transform: scale(1.05);
                }
            ";
            break;
        case 'shadow':
            $css .= "
                .u-lift {
                    transition: box-shadow 0.3s ease;
                }
                .u-lift:hover {
                    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.2), 0 4px 6px -2px rgba(0, 0, 0, 0.1);
                }
            ";
            break;
        case 'color-shift':
            // ボタン背景色を少し明るくした色を計算
            $rgb = sscanf($button_bg_color, "#%02x%02x%02x");
            $lighter_color = sprintf("#%02x%02x%02x", 
                min(255, $rgb[0] + 30), 
                min(255, $rgb[1] + 30), 
                min(255, $rgb[2] + 30)
            );
            
            $css .= "
                .u-lift {
                    transition: background-color 0.3s ease, color 0.3s ease;
                }
                .u-lift:hover {
                    background-color: {$lighter_color} !important;
                }
            ";
            break;
    }
    
    wp_add_inline_style( 'arkhe-style', $css );
}
add_action( 'wp_enqueue_scripts', 'my_openai_hero_customizer_css' );

/**
 * Heroセクション (OpenAI Style) のカスタマイザープレビュー用のJavaScriptを登録
 */
function my_openai_hero_customize_preview_js() {
    wp_enqueue_script(
        'my-openai-hero-customizer',
        get_stylesheet_directory_uri() . '/assets/js/hero-customizer-preview.js',
        array( 'jquery', 'customize-preview' ),
        '1.0',
        true
    );
}
add_action( 'customize_preview_init', 'my_openai_hero_customize_preview_js' );
