<?php
/**
 * ヒーローセクションのカスタマイザー設定
 */

if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * ヒーローセクションのカスタマイザー設定を追加
 */
function my_openai_hero_customizer_settings( $wp_customize ) {
    // ヒーローセクションのセクションを追加
    $wp_customize->add_section( 'my_openai_hero_section', array(
        'title'    => __( 'ヒーローセクション設定', 'my-openai' ),
        'priority' => 30,
    ) );

    // 最小の高さ (vh)
    $wp_customize->add_setting( 'my_openai_hero_min_height', array(
        'default'           => '80',
        'sanitize_callback' => 'absint',
    ) );
    $wp_customize->add_control( 'my_openai_hero_min_height', array(
        'label'       => __( '最小の高さ (vh)', 'my-openai' ),
        'section'     => 'my_openai_hero_section',
        'type'        => 'number',
        'input_attrs' => array(
            'min'  => 30,
            'max'  => 100,
            'step' => 5,
        ),
    ) );

    // 重ね色 (オーバーレイカラー)
    $wp_customize->add_setting( 'my_openai_hero_overlay_color', array(
        'default'           => '#000000',
        'sanitize_callback' => 'sanitize_hex_color',
    ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'my_openai_hero_overlay_color', array(
        'label'   => __( '重ね色 (オーバーレイカラー)', 'my-openai' ),
        'section' => 'my_openai_hero_section',
    ) ) );

    // 重ね色の不透明度
    $wp_customize->add_setting( 'my_openai_hero_overlay_opacity', array(
        'default'           => '0.5',
        'sanitize_callback' => 'my_openai_sanitize_opacity',
    ) );
    $wp_customize->add_control( 'my_openai_hero_overlay_opacity', array(
        'label'       => __( '重ね色の不透明度', 'my-openai' ),
        'section'     => 'my_openai_hero_section',
        'type'        => 'range',
        'input_attrs' => array(
            'min'  => 0,
            'max'  => 1,
            'step' => 0.05,
        ),
    ) );

    // 角丸 (px)
    $wp_customize->add_setting( 'my_openai_hero_border_radius', array(
        'default'           => '0',
        'sanitize_callback' => 'absint',
    ) );
    $wp_customize->add_control( 'my_openai_hero_border_radius', array(
        'label'       => __( '角丸 (px)', 'my-openai' ),
        'section'     => 'my_openai_hero_section',
        'type'        => 'range',
        'input_attrs' => array(
            'min'  => 0,
            'max'  => 50,
            'step' => 2,
        ),
    ) );

    // 内部コンテナのパディング
    $wp_customize->add_setting( 'my_openai_hero_padding', array(
        'default'           => '40',
        'sanitize_callback' => 'absint',
    ) );
    $wp_customize->add_control( 'my_openai_hero_padding', array(
        'label'       => __( '内部コンテナのパディング (px)', 'my-openai' ),
        'section'     => 'my_openai_hero_section',
        'type'        => 'number',
        'input_attrs' => array(
            'min'  => 0,
            'max'  => 100,
            'step' => 5,
        ),
    ) );

    // テキスト設定セクション
    $wp_customize->add_setting( 'my_openai_hero_text_heading', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_text_field',
    ) );
    $wp_customize->add_control( new WP_Customize_Heading_Control( $wp_customize, 'my_openai_hero_text_heading', array(
        'label'   => __( 'テキスト設定', 'my-openai' ),
        'section' => 'my_openai_hero_section',
    ) ) );

    // PC向け見出しフォントサイズ
    $wp_customize->add_setting( 'my_openai_hero_heading_font_size_pc', array(
        'default'           => '64',
        'sanitize_callback' => 'absint',
    ) );
    $wp_customize->add_control( 'my_openai_hero_heading_font_size_pc', array(
        'label'       => __( 'PC向け見出しフォントサイズ (px)', 'my-openai' ),
        'section'     => 'my_openai_hero_section',
        'type'        => 'number',
        'input_attrs' => array(
            'min'  => 20,
            'max'  => 120,
            'step' => 1,
        ),
    ) );

    // SP向け見出しフォントサイズ
    $wp_customize->add_setting( 'my_openai_hero_heading_font_size_sp', array(
        'default'           => '36',
        'sanitize_callback' => 'absint',
    ) );
    $wp_customize->add_control( 'my_openai_hero_heading_font_size_sp', array(
        'label'       => __( 'SP向け見出しフォントサイズ (px)', 'my-openai' ),
        'section'     => 'my_openai_hero_section',
        'type'        => 'number',
        'input_attrs' => array(
            'min'  => 16,
            'max'  => 80,
            'step' => 1,
        ),
    ) );

    // 見出しフォントウェイト
    $wp_customize->add_setting( 'my_openai_hero_heading_font_weight', array(
        'default'           => '700',
        'sanitize_callback' => 'my_openai_sanitize_font_weight',
    ) );
    $wp_customize->add_control( 'my_openai_hero_heading_font_weight', array(
        'label'   => __( '見出しフォントウェイト', 'my-openai' ),
        'section' => 'my_openai_hero_section',
        'type'    => 'select',
        'choices' => array(
            '400' => __( 'レギュラー (400)', 'my-openai' ),
            '500' => __( 'ミディアム (500)', 'my-openai' ),
            '600' => __( 'セミボールド (600)', 'my-openai' ),
            '700' => __( 'ボールド (700)', 'my-openai' ),
            '800' => __( 'エクストラボールド (800)', 'my-openai' ),
        ),
    ) );

    // 見出し行の高さ
    $wp_customize->add_setting( 'my_openai_hero_heading_line_height', array(
        'default'           => '1.2',
        'sanitize_callback' => 'my_openai_sanitize_line_height',
    ) );
    $wp_customize->add_control( 'my_openai_hero_heading_line_height', array(
        'label'       => __( '見出し行の高さ', 'my-openai' ),
        'section'     => 'my_openai_hero_section',
        'type'        => 'range',
        'input_attrs' => array(
            'min'  => 0.8,
            'max'  => 2,
            'step' => 0.1,
        ),
    ) );

    // PC向け段落フォントサイズ
    $wp_customize->add_setting( 'my_openai_hero_paragraph_font_size_pc', array(
        'default'           => '20',
        'sanitize_callback' => 'absint',
    ) );
    $wp_customize->add_control( 'my_openai_hero_paragraph_font_size_pc', array(
        'label'       => __( 'PC向け段落フォントサイズ (px)', 'my-openai' ),
        'section'     => 'my_openai_hero_section',
        'type'        => 'number',
        'input_attrs' => array(
            'min'  => 12,
            'max'  => 40,
            'step' => 1,
        ),
    ) );

    // SP向け段落フォントサイズ
    $wp_customize->add_setting( 'my_openai_hero_paragraph_font_size_sp', array(
        'default'           => '16',
        'sanitize_callback' => 'absint',
    ) );
    $wp_customize->add_control( 'my_openai_hero_paragraph_font_size_sp', array(
        'label'       => __( 'SP向け段落フォントサイズ (px)', 'my-openai' ),
        'section'     => 'my_openai_hero_section',
        'type'        => 'number',
        'input_attrs' => array(
            'min'  => 10,
            'max'  => 30,
            'step' => 1,
        ),
    ) );

    // テキスト配置
    $wp_customize->add_setting( 'my_openai_hero_text_align', array(
        'default'           => 'center',
        'sanitize_callback' => 'my_openai_sanitize_text_align',
    ) );
    $wp_customize->add_control( 'my_openai_hero_text_align', array(
        'label'   => __( 'テキスト配置', 'my-openai' ),
        'section' => 'my_openai_hero_section',
        'type'    => 'select',
        'choices' => array(
            'left'   => __( '左揃え', 'my-openai' ),
            'center' => __( '中央揃え', 'my-openai' ),
            'right'  => __( '右揃え', 'my-openai' ),
        ),
    ) );

    // アニメーション設定セクション
    $wp_customize->add_setting( 'my_openai_hero_animation_heading', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_text_field',
    ) );
    $wp_customize->add_control( new WP_Customize_Heading_Control( $wp_customize, 'my_openai_hero_animation_heading', array(
        'label'   => __( 'アニメーション設定', 'my-openai' ),
        'section' => 'my_openai_hero_section',
    ) ) );

    // アニメーション有効/無効
    $wp_customize->add_setting( 'my_openai_hero_animation_enable', array(
        'default'           => true,
        'sanitize_callback' => 'my_openai_sanitize_checkbox',
    ) );
    $wp_customize->add_control( 'my_openai_hero_animation_enable', array(
        'label'   => __( 'アニメーションを有効にする', 'my-openai' ),
        'section' => 'my_openai_hero_section',
        'type'    => 'checkbox',
    ) );

    // アニメーションタイプ
    $wp_customize->add_setting( 'my_openai_hero_animation_type', array(
        'default'           => 'fade-in',
        'sanitize_callback' => 'my_openai_sanitize_animation_type',
    ) );
    $wp_customize->add_control( 'my_openai_hero_animation_type', array(
        'label'   => __( 'アニメーションタイプ', 'my-openai' ),
        'section' => 'my_openai_hero_section',
        'type'    => 'select',
        'choices' => array(
            'fade-in'     => __( 'フェードイン', 'my-openai' ),
            'slide-up'    => __( '下から上へスライド', 'my-openai' ),
            'slide-left'  => __( '右から左へスライド', 'my-openai' ),
            'slide-right' => __( '左から右へスライド', 'my-openai' ),
            'zoom-in'     => __( 'ズームイン', 'my-openai' ),
            'bounce'      => __( 'バウンス', 'my-openai' ),
        ),
    ) );

    // アニメーション速度
    $wp_customize->add_setting( 'my_openai_hero_animation_speed', array(
        'default'           => '0.8',
        'sanitize_callback' => 'my_openai_sanitize_animation_speed',
    ) );
    $wp_customize->add_control( 'my_openai_hero_animation_speed', array(
        'label'       => __( 'アニメーション速度 (秒)', 'my-openai' ),
        'section'     => 'my_openai_hero_section',
        'type'        => 'range',
        'input_attrs' => array(
            'min'  => 0.1,
            'max'  => 3,
            'step' => 0.1,
        ),
    ) );

    // アニメーション遅延
    $wp_customize->add_setting( 'my_openai_hero_animation_delay', array(
        'default'           => '0.2',
        'sanitize_callback' => 'my_openai_sanitize_animation_delay',
    ) );
    $wp_customize->add_control( 'my_openai_hero_animation_delay', array(
        'label'       => __( 'アニメーション遅延 (秒)', 'my-openai' ),
        'section'     => 'my_openai_hero_section',
        'type'        => 'range',
        'input_attrs' => array(
            'min'  => 0,
            'max'  => 2,
            'step' => 0.1,
        ),
    ) );

    // ボタン設定セクション
    $wp_customize->add_setting( 'my_openai_hero_button_heading', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_text_field',
    ) );
    $wp_customize->add_control( new WP_Customize_Heading_Control( $wp_customize, 'my_openai_hero_button_heading', array(
        'label'   => __( 'ボタン設定', 'my-openai' ),
        'section' => 'my_openai_hero_section',
    ) ) );

    // ボタン背景色
    $wp_customize->add_setting( 'my_openai_hero_button_bg_color', array(
        'default'           => '#10a37f',
        'sanitize_callback' => 'sanitize_hex_color',
    ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'my_openai_hero_button_bg_color', array(
        'label'   => __( 'ボタン背景色', 'my-openai' ),
        'section' => 'my_openai_hero_section',
    ) ) );

    // ボタンテキスト色
    $wp_customize->add_setting( 'my_openai_hero_button_text_color', array(
        'default'           => '#ffffff',
        'sanitize_callback' => 'sanitize_hex_color',
    ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'my_openai_hero_button_text_color', array(
        'label'   => __( 'ボタンテキスト色', 'my-openai' ),
        'section' => 'my_openai_hero_section',
    ) ) );

    // ボタン角丸
    $wp_customize->add_setting( 'my_openai_hero_button_border_radius', array(
        'default'           => '4',
        'sanitize_callback' => 'absint',
    ) );
    $wp_customize->add_control( 'my_openai_hero_button_border_radius', array(
        'label'       => __( 'ボタン角丸 (px)', 'my-openai' ),
        'section'     => 'my_openai_hero_section',
        'type'        => 'range',
        'input_attrs' => array(
            'min'  => 0,
            'max'  => 50,
            'step' => 1,
        ),
    ) );

    // ボタンホバーエフェクト
    $wp_customize->add_setting( 'my_openai_hero_button_hover_effect', array(
        'default'           => 'lift',
        'sanitize_callback' => 'my_openai_sanitize_hover_effect',
    ) );
    $wp_customize->add_control( 'my_openai_hero_button_hover_effect', array(
        'label'   => __( 'ボタンホバーエフェクト', 'my-openai' ),
        'section' => 'my_openai_hero_section',
        'type'    => 'select',
        'choices' => array(
            'none'         => __( 'なし', 'my-openai' ),
            'lift'         => __( '浮き上がり', 'my-openai' ),
            'scale'        => __( '拡大', 'my-openai' ),
            'shadow'       => __( '影の強調', 'my-openai' ),
            'color-shift'  => __( '色の反転', 'my-openai' ),
        ),
    ) );
}
add_action( 'customize_register', 'my_openai_hero_customizer_settings' );

/**
 * サニタイズ関数
 */
function my_openai_sanitize_opacity( $input ) {
    return floatval( max( 0, min( 1, $input ) ) );
}

function my_openai_sanitize_font_weight( $input ) {
    $valid = array( '400', '500', '600', '700', '800' );
    return in_array( $input, $valid ) ? $input : '700';
}

function my_openai_sanitize_line_height( $input ) {
    return floatval( max( 0.8, min( 2, $input ) ) );
}

function my_openai_sanitize_text_align( $input ) {
    $valid = array( 'left', 'center', 'right' );
    return in_array( $input, $valid ) ? $input : 'center';
}

function my_openai_sanitize_checkbox( $input ) {
    return ( $input === true || $input === '1' ) ? true : false;
}

function my_openai_sanitize_animation_type( $input ) {
    $valid = array( 'fade-in', 'slide-up', 'slide-left', 'slide-right', 'zoom-in', 'bounce' );
    return in_array( $input, $valid ) ? $input : 'fade-in';
}

function my_openai_sanitize_animation_speed( $input ) {
    return floatval( max( 0.1, min( 3, $input ) ) );
}

function my_openai_sanitize_animation_delay( $input ) {
    return floatval( max( 0, min( 2, $input ) ) );
}

function my_openai_sanitize_hover_effect( $input ) {
    $valid = array( 'none', 'lift', 'scale', 'shadow', 'color-shift' );
    return in_array( $input, $valid ) ? $input : 'lift';
}

/**
 * カスタムコントロールクラス（見出し用）
 */
if ( class_exists( 'WP_Customize_Control' ) && ! class_exists( 'WP_Customize_Heading_Control' ) ) {
    class WP_Customize_Heading_Control extends WP_Customize_Control {
        public $type = 'heading';

        public function render_content() {
            ?>
            <h3 style="margin-top: 20px; border-bottom: 1px solid #ddd; padding-bottom: 5px; color: #333; margin-bottom: 10px;"><?php echo esc_html( $this->label ); ?></h3>
            <?php
        }
    }
} 