<?php
/**
 * Template part for displaying the latest news section on the front page.
 */

?>
<section class="front-latest-news">
	<div class="container"> <?php // Adjust container class as needed ?>
		<header class="section-header">
			<h2 class="section-title">最新ニュース</h2>
			<?php
				// Get the URL for the blog page (where posts are listed)
				$posts_page_id = get_option( 'page_for_posts' );
				$posts_page_url = $posts_page_id ? get_permalink( $posts_page_id ) : get_home_url();
			?>
			<a href="<?php echo esc_url( $posts_page_url ); ?>" class="view-all-link">すべて見る</a>
		</header>

		<div class="news-grid"> <?php // Grid container for news items ?>
			<?php
			$args = array(
				'post_type'      => 'post', // Get standard posts
				'post_status'    => 'publish',
				'posts_per_page' => 6,       // Show 6 posts (like OpenAI)
				'orderby'        => 'date',
				'order'          => 'DESC',
			);

			$latest_posts_query = new WP_Query( $args );

			if ( $latest_posts_query->have_posts() ) :
				while ( $latest_posts_query->have_posts() ) : $latest_posts_query->the_post();
					?>
					<article id="post-<?php the_ID(); ?>" <?php post_class('news-item'); ?>>
						<a href="<?php the_permalink(); ?>" class="news-item-link">
							<div class="news-item-thumbnail">
								<?php if ( has_post_thumbnail() ) : ?>
									<?php the_post_thumbnail('medium_large'); // Adjust thumbnail size as needed ?>
								<?php else : ?>
									<img src="<?php echo get_template_directory_uri(); ?>/assets/images/placeholder.png" alt="" width="300" height="200"> <?php // Add a placeholder image ?>
								<?php endif; ?>
							</div>
							<div class="news-item-content">
								<h3 class="news-item-title"><?php the_title(); ?></h3>
								<div class="news-item-meta">
									<?php
									// Display category (e.g., 製品, リリース) - Choose one category or customize
									$categories = get_the_category();
									if ( ! empty( $categories ) ) {
										echo '<span class="news-item-category">' . esc_html( $categories[0]->name ) . '</span>';
									}
									?>
									<time class="news-item-date" datetime="<?php echo get_the_date( 'c' ); ?>"><?php echo get_the_date( 'Y年n月j日' ); ?></time>
								</div>
							</div>
						</a>
					</article>
					<?php
				endwhile;
				wp_reset_postdata(); // Restore original Post Data
			else :
				// no posts found
			endif;
			?>
		</div><?php // .news-grid ?>
	</div> <?php // .container ?>
</section><?php // .front-latest-news ?> 